@@ -2,7 +2,7 @@
 // 
 //  Solution of linear systems involved in the Levenberg - Marquardt
 //  minimization algorithm
-//  Copyright (C) 2004  Manolis Lourakis (lourakis@ics.forth.gr)
+//  Copyright (C) 2004  Manolis Lourakis (lourakis at ics forth gr)
 //  Institute of Computer Science, Foundation for Research & Technology - Hellas
 //  Heraklion, Crete, Greece.
 //
@@ -26,6 +26,7 @@
 #error This file should not be compiled directly!
 #endif
 
+
 #ifdef LINSOLVERS_RETAIN_MEMORY
 #define __STATIC__ static
 #else
@@ -36,16 +37,23 @@
 
 /* prototypes of LAPACK routines */
 
-#define GEQRF LM_ADD_PREFIX(geqrf_)
-#define ORGQR LM_ADD_PREFIX(orgqr_)
-#define TRTRS LM_ADD_PREFIX(trtrs_)
-#define POTF2 LM_ADD_PREFIX(potf2_)
-#define POTRF LM_ADD_PREFIX(potrf_)
-#define GETRF LM_ADD_PREFIX(getrf_)
-#define GETRS LM_ADD_PREFIX(getrs_)
-#define GESVD LM_ADD_PREFIX(gesvd_)
-#define GESDD LM_ADD_PREFIX(gesdd_)
+#define GEQRF LM_MK_LAPACK_NAME(geqrf)
+#define ORGQR LM_MK_LAPACK_NAME(orgqr)
+#define TRTRS LM_MK_LAPACK_NAME(trtrs)
+#define POTF2 LM_MK_LAPACK_NAME(potf2)
+#define POTRF LM_MK_LAPACK_NAME(potrf)
+#define POTRS LM_MK_LAPACK_NAME(potrs)
+#define GETRF LM_MK_LAPACK_NAME(getrf)
+#define GETRS LM_MK_LAPACK_NAME(getrs)
+#define GESVD LM_MK_LAPACK_NAME(gesvd)
+#define GESDD LM_MK_LAPACK_NAME(gesdd)
+#define SYTRF LM_MK_LAPACK_NAME(sytrf)
+#define SYTRS LM_MK_LAPACK_NAME(sytrs)
+#define PLASMA_POSV LM_CAT_(PLASMA_, LM_ADD_PREFIX(posv))
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 /* QR decomposition */
 extern int GEQRF(int *m, int *n, LM_REAL *a, int *lda, LM_REAL *tau, LM_REAL *work, int *lwork, int *info);
 extern int ORGQR(int *m, int *n, int *k, LM_REAL *a, int *lda, LM_REAL *tau, LM_REAL *work, int *lwork, int *info);
@@ -53,9 +61,10 @@ extern int ORGQR(int *m, int *n, int *k, LM_REAL *a, int *lda, LM_REAL *tau, LM_
 /* solution of triangular systems */
 extern int TRTRS(char *uplo, char *trans, char *diag, int *n, int *nrhs, LM_REAL *a, int *lda, LM_REAL *b, int *ldb, int *info);
 
-/* cholesky decomposition */
+/* Cholesky decomposition and systems solution */
 extern int POTF2(char *uplo, int *n, LM_REAL *a, int *lda, int *info);
 extern int POTRF(char *uplo, int *n, LM_REAL *a, int *lda, int *info); /* block version of dpotf2 */
+extern int POTRS(char *uplo, int *n, int *nrhs, LM_REAL *a, int *lda, LM_REAL *b, int *ldb, int *info);
 
 /* LU decomposition and systems solution */
 extern int GETRF(int *m, int *n, LM_REAL *a, int *lda, int *ipiv, int *info);
@@ -71,12 +80,21 @@ extern int GESVD(char *jobu, char *jobvt, int *m, int *n, LM_REAL *a, int *lda,
 extern int GESDD(char *jobz, int *m, int *n, LM_REAL *a, int *lda, LM_REAL *s, LM_REAL *u, int *ldu, LM_REAL *vt, int *ldvt,
                    LM_REAL *work, int *lwork, int *iwork, int *info);
 
+/* LDLt/UDUt factorization and systems solution */
+extern int SYTRF(char *uplo, int *n, LM_REAL *a, int *lda, int *ipiv, LM_REAL *work, int *lwork, int *info);
+extern int SYTRS(char *uplo, int *n, int *nrhs, LM_REAL *a, int *lda, int *ipiv, LM_REAL *b, int *ldb, int *info);
+#ifdef __cplusplus
+}
+#endif
+
 /* precision-specific definitions */
 #define AX_EQ_B_QR LM_ADD_PREFIX(Ax_eq_b_QR)
 #define AX_EQ_B_QRLS LM_ADD_PREFIX(Ax_eq_b_QRLS)
 #define AX_EQ_B_CHOL LM_ADD_PREFIX(Ax_eq_b_Chol)
 #define AX_EQ_B_LU LM_ADD_PREFIX(Ax_eq_b_LU)
 #define AX_EQ_B_SVD LM_ADD_PREFIX(Ax_eq_b_SVD)
+#define AX_EQ_B_BK LM_ADD_PREFIX(Ax_eq_b_BK)
+#define AX_EQ_B_PLASMA_CHOL LM_ADD_PREFIX(Ax_eq_b_PLASMA_Chol)
 
 /*
  * This function returns the solution of Ax = b
@@ -88,7 +106,7 @@ extern int GESDD(char *jobz, int *m, int *n, LM_REAL *a, int *lda, LM_REAL *s, L
  *
  * A is mxm, b is mx1
  *
- * The function returns 0 in case of error, 1 if successfull
+ * The function returns 0 in case of error, 1 if successful
  *
  * This function is often called repetitively to solve problems of identical
  * dimensions. To avoid repetitive malloc's and free's, allocated memory is
@@ -100,27 +118,40 @@ int AX_EQ_B_QR(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m)
 __STATIC__ LM_REAL *buf=NULL;
 __STATIC__ int buf_sz=0;
 
-LM_REAL *a, *qtb, *tau, *r, *work;
-int a_sz, qtb_sz, tau_sz, r_sz, tot_sz;
+static int nb=0; /* no __STATIC__ decl. here! */
+
+LM_REAL *a, *tau, *r, *work;
+int a_sz, tau_sz, r_sz, tot_sz;
 register int i, j;
 int info, worksz, nrhs=1;
 register LM_REAL sum;
 
+    if(!A)
 #ifdef LINSOLVERS_RETAIN_MEMORY
-    if(!A){
+    {
       if(buf) free(buf);
+      buf=NULL;
       buf_sz=0;
+
       return 1;
     }
+#else
+      return 1; /* NOP */
 #endif /* LINSOLVERS_RETAIN_MEMORY */
    
     /* calculate required memory size */
     a_sz=m*m;
-    qtb_sz=m;
     tau_sz=m;
     r_sz=m*m; /* only the upper triangular part really needed */
-    worksz=3*m; /* this is probably too much */
-    tot_sz=a_sz + qtb_sz + tau_sz + r_sz + worksz;
+    if(!nb){
+      LM_REAL tmp;
+
+      worksz=-1; // workspace query; optimal size is returned in tmp
+      GEQRF((int *)&m, (int *)&m, NULL, (int *)&m, NULL, (LM_REAL *)&tmp, (int *)&worksz, (int *)&info);
+      nb=((int)tmp)/m; // optimal worksize is m*nb
+    }
+    worksz=nb*m;
+    tot_sz=a_sz + tau_sz + r_sz + worksz;
 
 #ifdef LINSOLVERS_RETAIN_MEMORY
     if(tot_sz>buf_sz){ /* insufficient memory, allocate a "big" memory chunk at once */
@@ -143,8 +174,7 @@ register LM_REAL sum;
 #endif /* LINSOLVERS_RETAIN_MEMORY */
 
     a=buf;
-    qtb=a+a_sz;
-    tau=qtb+qtb_sz;
+    tau=a+a_sz;
     r=tau+tau_sz;
     work=r+r_sz;
 
@@ -172,8 +202,7 @@ register LM_REAL sum;
   }
 
   /* R is stored in the upper triangular part of a; copy it in r so that ORGQR() below won't destroy it */ 
-  for(i=0; i<r_sz; i++)
-    r[i]=a[i];
+  memcpy(r, a, r_sz*sizeof(LM_REAL));
 
   /* compute Q using the elementary reflectors computed by the above decomposition */
   ORGQR((int *)&m, (int *)&m, (int *)&m, a, (int *)&m, tau, work, (int *)&worksz, (int *)&info);
@@ -192,15 +221,15 @@ register LM_REAL sum;
     }
   }
 
-  /* Q is now in a; compute Q^T b in qtb */
+  /* Q is now in a; compute Q^T b in x */
   for(i=0; i<m; i++){
     for(j=0, sum=0.0; j<m; j++)
       sum+=a[i*m+j]*B[j];
-    qtb[i]=sum;
+    x[i]=sum;
   }
 
   /* solve the linear system R x = Q^t b */
-  TRTRS("U", "N", "N", (int *)&m, (int *)&nrhs, r, (int *)&m, qtb, (int *)&m, &info);
+  TRTRS("U", "N", "N", (int *)&m, (int *)&nrhs, r, (int *)&m, x, (int *)&m, &info);
   /* error treatment */
   if(info!=0){
     if(info<0){
@@ -217,10 +246,6 @@ register LM_REAL sum;
     }
   }
 
-	/* copy the result in x */
-	for(i=0; i<m; i++)
-    x[i]=qtb[i];
-
 #ifndef LINSOLVERS_RETAIN_MEMORY
   free(buf);
 #endif
@@ -240,7 +265,7 @@ register LM_REAL sum;
  *
  * A is mxn, b is mx1
  *
- * The function returns 0 in case of error, 1 if successfull
+ * The function returns 0 in case of error, 1 if successful
  *
  * This function is often called repetitively to solve problems of identical
  * dimensions. To avoid repetitive malloc's and free's, allocated memory is
@@ -252,18 +277,25 @@ int AX_EQ_B_QRLS(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m, int n)
 __STATIC__ LM_REAL *buf=NULL;
 __STATIC__ int buf_sz=0;
 
-LM_REAL *a, *atb, *tau, *r, *work;
-int a_sz, atb_sz, tau_sz, r_sz, tot_sz;
+static int nb=0; /* no __STATIC__ decl. here! */
+
+LM_REAL *a, *tau, *r, *work;
+int a_sz, tau_sz, r_sz, tot_sz;
 register int i, j;
 int info, worksz, nrhs=1;
 register LM_REAL sum;
    
+    if(!A)
 #ifdef LINSOLVERS_RETAIN_MEMORY
-    if(!A){
+    {
       if(buf) free(buf);
+      buf=NULL;
       buf_sz=0;
+
       return 1;
     }
+#else
+      return 1; /* NOP */
 #endif /* LINSOLVERS_RETAIN_MEMORY */
    
     if(m<n){
@@ -273,11 +305,17 @@ register LM_REAL sum;
       
     /* calculate required memory size */
     a_sz=m*n;
-    atb_sz=n;
     tau_sz=n;
     r_sz=n*n;
-    worksz=3*n; /* this is probably too much */
-    tot_sz=a_sz + atb_sz + tau_sz + r_sz + worksz;
+    if(!nb){
+      LM_REAL tmp;
+
+      worksz=-1; // workspace query; optimal size is returned in tmp
+      GEQRF((int *)&m, (int *)&m, NULL, (int *)&m, NULL, (LM_REAL *)&tmp, (int *)&worksz, (int *)&info);
+      nb=((int)tmp)/m; // optimal worksize is m*nb
+    }
+    worksz=nb*m;
+    tot_sz=a_sz + tau_sz + r_sz + worksz;
 
 #ifdef LINSOLVERS_RETAIN_MEMORY
     if(tot_sz>buf_sz){ /* insufficient memory, allocate a "big" memory chunk at once */
@@ -300,8 +338,7 @@ register LM_REAL sum;
 #endif /* LINSOLVERS_RETAIN_MEMORY */
 
     a=buf;
-    atb=a+a_sz;
-    tau=atb+atb_sz;
+    tau=a+a_sz;
     r=tau+tau_sz;
     work=r+r_sz;
 
@@ -310,11 +347,11 @@ register LM_REAL sum;
 		for(j=0; j<n; j++)
 			a[i+j*m]=A[i*n+j];
 
-  /* compute A^T b in atb */
+  /* compute A^T b in x */
   for(i=0; i<n; i++){
     for(j=0, sum=0.0; j<m; j++)
       sum+=A[j*n+i]*B[j];
-    atb[i]=sum;
+    x[i]=sum;
   }
 
   /* QR decomposition of A */
@@ -346,7 +383,7 @@ register LM_REAL sum;
   }
 
   /* solve the linear system R^T y = A^t b */
-  TRTRS("U", "T", "N", (int *)&n, (int *)&nrhs, r, (int *)&n, atb, (int *)&n, &info);
+  TRTRS("U", "T", "N", (int *)&n, (int *)&nrhs, r, (int *)&n, x, (int *)&n, &info);
   /* error treatment */
   if(info!=0){
     if(info<0){
@@ -364,7 +401,7 @@ register LM_REAL sum;
   }
 
   /* solve the linear system R x = y */
-  TRTRS("U", "N", "N", (int *)&n, (int *)&nrhs, r, (int *)&n, atb, (int *)&n, &info);
+  TRTRS("U", "N", "N", (int *)&n, (int *)&nrhs, r, (int *)&n, x, (int *)&n, &info);
   /* error treatment */
   if(info!=0){
     if(info<0){
@@ -381,10 +418,6 @@ register LM_REAL sum;
     }
   }
 
-	/* copy the result in x */
-	for(i=0; i<n; i++)
-    x[i]=atb[i];
-
 #ifndef LINSOLVERS_RETAIN_MEMORY
   free(buf);
 #endif
@@ -397,13 +430,13 @@ register LM_REAL sum;
  *
  * The function assumes that A is symmetric & postive definite and employs
  * the Cholesky decomposition:
- * If A=U^T U with U upper triangular, the system to be solved becomes
- * (U^T U) x = b
- * This amount to solving U^T y = b for y and then U x = y for x
+ * If A=L L^T with L lower triangular, the system to be solved becomes
+ * (L L^T) x = b
+ * This amounts to solving L y = b for y and then L^T x = y for x
  *
  * A is mxm, b is mx1
  *
- * The function returns 0 in case of error, 1 if successfull
+ * The function returns 0 in case of error, 1 if successful
  *
  * This function is often called repetitively to solve problems of identical
  * dimensions. To avoid repetitive malloc's and free's, allocated memory is
@@ -415,23 +448,26 @@ int AX_EQ_B_CHOL(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m)
 __STATIC__ LM_REAL *buf=NULL;
 __STATIC__ int buf_sz=0;
 
-LM_REAL *a, *b;
-int a_sz, b_sz, tot_sz;
-register int i, j;
+LM_REAL *a;
+int a_sz, tot_sz;
 int info, nrhs=1;
    
+    if(!A)
 #ifdef LINSOLVERS_RETAIN_MEMORY
-    if(!A){
+    {
       if(buf) free(buf);
+      buf=NULL;
       buf_sz=0;
+
       return 1;
     }
+#else
+      return 1; /* NOP */
 #endif /* LINSOLVERS_RETAIN_MEMORY */
    
     /* calculate required memory size */
     a_sz=m*m;
-    b_sz=m;
-    tot_sz=a_sz + b_sz;
+    tot_sz=a_sz;
 
 #ifdef LINSOLVERS_RETAIN_MEMORY
     if(tot_sz>buf_sz){ /* insufficient memory, allocate a "big" memory chunk at once */
@@ -453,27 +489,26 @@ int info, nrhs=1;
       }
 #endif /* LINSOLVERS_RETAIN_MEMORY */
 
-    a=buf;
-    b=a+a_sz;
+  a=buf;
 
-  /* store A (column major!) into a anb B into b */
-	for(i=0; i<m; i++){
-		for(j=0; j<m; j++)
-			a[i+j*m]=A[i*m+j];
-
-    b[i]=B[i];
-  }
+  /* store A into a and B into x. A is assumed symmetric,
+   * hence no transposition is needed
+   */
+  memcpy(a, A, a_sz*sizeof(LM_REAL));
+  memcpy(x, B, m*sizeof(LM_REAL));
 
   /* Cholesky decomposition of A */
-  POTF2("U", (int *)&m, a, (int *)&m, (int *)&info);
+  //POTF2("L", (int *)&m, a, (int *)&m, (int *)&info);
+  POTRF("L", (int *)&m, a, (int *)&m, (int *)&info);
   /* error treatment */
   if(info!=0){
     if(info<0){
-      fprintf(stderr, RCAT(RCAT("LAPACK error: illegal value for argument %d of ", POTF2) " in ", AX_EQ_B_CHOL) "()\n", -info);
+      fprintf(stderr, RCAT(RCAT(RCAT("LAPACK error: illegal value for argument %d of ", POTF2) "/", POTRF) " in ",
+                      AX_EQ_B_CHOL) "()\n", -info);
       exit(1);
     }
     else{
-      fprintf(stderr, RCAT(RCAT("LAPACK error: the leading minor of order %d is not positive definite,\nthe factorization could not be completed for ", POTF2) " in ", AX_EQ_B_CHOL) "()\n", info);
+      fprintf(stderr, RCAT(RCAT(RCAT("LAPACK error: the leading minor of order %d is not positive definite,\nthe factorization could not be completed for ", POTF2) "/", POTRF) " in ", AX_EQ_B_CHOL) "()\n", info);
 #ifndef LINSOLVERS_RETAIN_MEMORY
       free(buf);
 #endif
@@ -482,8 +517,16 @@ int info, nrhs=1;
     }
   }
 
-  /* solve the linear system U^T y = b */
-  TRTRS("U", "T", "N", (int *)&m, (int *)&nrhs, a, (int *)&m, b, (int *)&m, &info);
+  /* solve using the computed Cholesky in one lapack call */
+  POTRS("L", (int *)&m, (int *)&nrhs, a, (int *)&m, x, (int *)&m, &info);
+  if(info<0){
+    fprintf(stderr, RCAT(RCAT("LAPACK error: illegal value for argument %d of ", POTRS) " in ", AX_EQ_B_CHOL) "()\n", -info);
+    exit(1);
+  }
+
+#if 0
+  /* alternative: solve the linear system L y = b ... */
+  TRTRS("L", "N", "N", (int *)&m, (int *)&nrhs, a, (int *)&m, x, (int *)&m, &info);
   /* error treatment */
   if(info!=0){
     if(info<0){
@@ -500,8 +543,8 @@ int info, nrhs=1;
     }
   }
 
-  /* solve the linear system U x = y */
-  TRTRS("U", "N", "N", (int *)&m, (int *)&nrhs, a, (int *)&m, b, (int *)&m, &info);
+  /* ... solve the linear system L^T x = y */
+  TRTRS("L", "T", "N", (int *)&m, (int *)&nrhs, a, (int *)&m, x, (int *)&m, &info);
   /* error treatment */
   if(info!=0){
     if(info<0){
@@ -517,10 +560,7 @@ int info, nrhs=1;
       return 0;
     }
   }
-
-	/* copy the result in x */
-	for(i=0; i<m; i++)
-    x[i]=b[i];
+#endif /* 0 */
 
 #ifndef LINSOLVERS_RETAIN_MEMORY
   free(buf);
@@ -529,6 +569,155 @@ int info, nrhs=1;
 	return 1;
 }
 
+#ifdef HAVE_PLASMA
+
+/* Linear algebra using PLASMA parallel library for multicore CPUs.
+ * http://icl.cs.utk.edu/plasma/
+ *
+ * WARNING: BLAS multithreading should be disabled, e.g. setenv MKL_NUM_THREADS 1
+ */
+
+#ifndef _LM_PLASMA_MISC_
+/* avoid multiple inclusion of helper code */
+#define _LM_PLASMA_MISC_
+
+#include <plasma.h>
+#include <cblas.h>
+#include <lapacke.h>
+#include <plasma_tmg.h>
+#include <core_blas.h>
+
+/* programmatically determine the number of cores on the current machine */
+#ifdef _WIN32
+#include <windows.h>
+#elif __linux
+#include <unistd.h>
+#endif
+static int getnbcores()
+{
+#ifdef _WIN32
+  SYSTEM_INFO sysinfo;
+  GetSystemInfo(&sysinfo);
+  return sysinfo.dwNumberOfProcessors;
+#elif __linux
+  return sysconf(_SC_NPROCESSORS_ONLN);
+#else // unknown system
+  return 2<<1; // will be halved by right shift below
+#endif
+}
+
+static int PLASMA_ncores=-(getnbcores()>>1); // >0 if PLASMA initialized, <0 otherwise
+
+/* user-specified number of cores */
+void levmar_PLASMA_setnbcores(int cores)
+{
+  PLASMA_ncores=(cores>0)? -cores : ((cores)? cores : -2);
+}
+#endif /* _LM_PLASMA_MISC_ */
+
+/*
+ * This function returns the solution of Ax=b
+ *
+ * The function assumes that A is symmetric & positive definite and employs the
+ * Cholesky decomposition implemented by PLASMA for homogeneous multicore processors.
+ *
+ * A is mxm, b is mx1
+ *
+ * The function returns 0 in case of error, 1 if successful
+ *
+ * This function is often called repetitively to solve problems of identical
+ * dimensions. To avoid repetitive malloc's and free's, allocated memory is
+ * retained between calls and free'd-malloc'ed when not of the appropriate size.
+ * A call with NULL as the first argument forces this memory to be released.
+ */
+int AX_EQ_B_PLASMA_CHOL(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m)
+{
+__STATIC__ LM_REAL *buf=NULL;
+__STATIC__ int buf_sz=0;
+
+LM_REAL *a;
+int a_sz, tot_sz;
+int info, nrhs=1;
+
+    if(A==NULL){
+#ifdef LINSOLVERS_RETAIN_MEMORY
+      if(buf) free(buf);
+      buf=NULL;
+      buf_sz=0;
+#endif /* LINSOLVERS_RETAIN_MEMORY */
+
+      PLASMA_Finalize();
+      PLASMA_ncores=-PLASMA_ncores;
+
+      return 1;
+    }
+
+    /* calculate required memory size */
+    a_sz=m*m;
+    tot_sz=a_sz;
+
+#ifdef LINSOLVERS_RETAIN_MEMORY
+    if(tot_sz>buf_sz){ /* insufficient memory, allocate a "big" memory chunk at once */
+      if(buf) free(buf); /* free previously allocated memory */
+
+      buf_sz=tot_sz;
+      buf=(LM_REAL *)malloc(buf_sz*sizeof(LM_REAL));
+      if(!buf){
+        fprintf(stderr, RCAT("memory allocation in ", AX_EQ_B_PLASMA_CHOL) "() failed!\n");
+        exit(1);
+      }
+    }
+#else
+    buf_sz=tot_sz;
+    buf=(LM_REAL *)malloc(buf_sz*sizeof(LM_REAL));
+    if(!buf){
+      fprintf(stderr, RCAT("memory allocation in ", AX_EQ_B_PLASMA_CHOL) "() failed!\n");
+      exit(1);
+    }
+#endif /* LINSOLVERS_RETAIN_MEMORY */
+
+    a=buf;
+
+    /* store A into a and B into x; A is assumed to be symmetric,
+     * hence no transposition is needed
+     */
+    memcpy(a, A, a_sz*sizeof(LM_REAL));
+    memcpy(x, B, m*sizeof(LM_REAL));
+
+  /* initialize PLASMA */
+  if(PLASMA_ncores<0){
+    PLASMA_ncores=-PLASMA_ncores;
+    PLASMA_Init(PLASMA_ncores);
+    fprintf(stderr, RCAT("\n", AX_EQ_B_PLASMA_CHOL) "(): PLASMA is running on %d cores.\n\n", PLASMA_ncores);
+  }
+  
+  /* Solve the linear system */
+  info=PLASMA_POSV(PlasmaLower, m, 1, a, m, x, m);
+  /* error treatment */
+  if(info!=0){
+    if(info<0){
+      fprintf(stderr, RCAT(RCAT("LAPACK error: illegal value for argument %d of ", PLASMA_POSV) " in ",
+                      AX_EQ_B_PLASMA_CHOL) "()\n", -info);
+      exit(1);
+    }
+    else{
+      fprintf(stderr, RCAT(RCAT("LAPACK error: the leading minor of order %d is not positive definite,\n"
+                                "the factorization could not be completed for ", PLASMA_POSV) " in ", AX_EQ_B_CHOL) "()\n", info);
+#ifndef LINSOLVERS_RETAIN_MEMORY
+      free(buf);
+#endif
+      return 0;
+    }
+  }
+
+#ifndef LINSOLVERS_RETAIN_MEMORY
+  free(buf);
+#endif
+
+	return 1;
+}
+#endif /* HAVE_PLASMA */
+
 /*
  * This function returns the solution of Ax = b
  *
@@ -539,8 +728,7 @@ int info, nrhs=1;
  *
  * A is mxm, b is mx1
  *
- * The function returns 0 in case of error,
- * 1 if successfull
+ * The function returns 0 in case of error, 1 if successful
  *
  * This function is often called repetitively to solve problems of identical
  * dimensions. To avoid repetitive malloc's and free's, allocated memory is
@@ -552,32 +740,35 @@ int AX_EQ_B_LU(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m)
 __STATIC__ LM_REAL *buf=NULL;
 __STATIC__ int buf_sz=0;
 
-int a_sz, ipiv_sz, b_sz, work_sz, tot_sz;
+int a_sz, ipiv_sz, tot_sz;
 register int i, j;
 int info, *ipiv, nrhs=1;
-LM_REAL *a, *b, *work;
+LM_REAL *a;
    
+    if(!A)
 #ifdef LINSOLVERS_RETAIN_MEMORY
-    if(!A){
+    {
       if(buf) free(buf);
+      buf=NULL;
       buf_sz=0;
+
       return 1;
     }
+#else
+      return 1; /* NOP */
 #endif /* LINSOLVERS_RETAIN_MEMORY */
    
     /* calculate required memory size */
     ipiv_sz=m;
     a_sz=m*m;
-    b_sz=m;
-    work_sz=100*m; /* this is probably too much */
-    tot_sz=ipiv_sz + a_sz + b_sz + work_sz; // ipiv_sz counted as LM_REAL here, no harm is done though
+    tot_sz=a_sz*sizeof(LM_REAL) + ipiv_sz*sizeof(int); /* should be arranged in that order for proper doubles alignment */
 
 #ifdef LINSOLVERS_RETAIN_MEMORY
     if(tot_sz>buf_sz){ /* insufficient memory, allocate a "big" memory chunk at once */
       if(buf) free(buf); /* free previously allocated memory */
 
       buf_sz=tot_sz;
-      buf=(LM_REAL *)malloc(buf_sz*sizeof(LM_REAL));
+      buf=(LM_REAL *)malloc(buf_sz);
       if(!buf){
         fprintf(stderr, RCAT("memory allocation in ", AX_EQ_B_LU) "() failed!\n");
         exit(1);
@@ -585,24 +776,22 @@ LM_REAL *a, *b, *work;
     }
 #else
       buf_sz=tot_sz;
-      buf=(LM_REAL *)malloc(buf_sz*sizeof(LM_REAL));
+      buf=(LM_REAL *)malloc(buf_sz);
       if(!buf){
         fprintf(stderr, RCAT("memory allocation in ", AX_EQ_B_LU) "() failed!\n");
         exit(1);
       }
 #endif /* LINSOLVERS_RETAIN_MEMORY */
 
-    ipiv=(int *)buf;
-    a=(LM_REAL *)(ipiv + ipiv_sz);
-    b=a+a_sz;
-    work=b+b_sz;
+    a=buf;
+    ipiv=(int *)(a+a_sz);
 
-    /* store A (column major!) into a and B into b */
+    /* store A (column major!) into a and B into x */
 	  for(i=0; i<m; i++){
 		  for(j=0; j<m; j++)
         a[i+j*m]=A[i*m+j];
 
-      b[i]=B[i];
+      x[i]=B[i];
     }
 
   /* LU decomposition for A */
@@ -623,7 +812,7 @@ LM_REAL *a, *b, *work;
 	}
 
   /* solve the system with the computed LU */
-  GETRS("N", (int *)&m, (int *)&nrhs, a, (int *)&m, ipiv, b, (int *)&m, (int *)&info);
+  GETRS("N", (int *)&m, (int *)&nrhs, a, (int *)&m, ipiv, x, (int *)&m, (int *)&info);
 	if(info!=0){
 		if(info<0){
 			fprintf(stderr, RCAT(RCAT("argument %d of ", GETRS) " illegal in ", AX_EQ_B_LU) "()\n", -info);
@@ -639,11 +828,6 @@ LM_REAL *a, *b, *work;
 		}
 	}
 
-	/* copy the result in x */
-	for(i=0; i<m; i++){
-		x[i]=b[i];
-	}
-
 #ifndef LINSOLVERS_RETAIN_MEMORY
   free(buf);
 #endif
@@ -661,7 +845,7 @@ LM_REAL *a, *b, *work;
  *
  * A is mxm, b is mx1.
  *
- * The function returns 0 in case of error, 1 if successfull
+ * The function returns 0 in case of error, 1 if successful
  *
  * This function is often called repetitively to solve problems of identical
  * dimensions. To avoid repetitive malloc's and free's, allocated memory is
@@ -672,7 +856,7 @@ int AX_EQ_B_SVD(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m)
 {
 __STATIC__ LM_REAL *buf=NULL;
 __STATIC__ int buf_sz=0;
-static LM_REAL eps=CNST(-1.0);
+static LM_REAL eps=LM_CNST(-1.0);
 
 register int i, j;
 LM_REAL *a, *u, *s, *vt, *work;
@@ -681,21 +865,35 @@ LM_REAL thresh, one_over_denom;
 register LM_REAL sum;
 int info, rank, worksz, *iwork, iworksz;
    
+    if(!A)
 #ifdef LINSOLVERS_RETAIN_MEMORY
-    if(!A){
+    {
       if(buf) free(buf);
+      buf=NULL;
       buf_sz=0;
+
       return 1;
     }
+#else
+      return 1; /* NOP */
 #endif /* LINSOLVERS_RETAIN_MEMORY */
    
   /* calculate required memory size */
-  worksz=16*m; /* more than needed */
+#if 1 /* use optimal size */
+  worksz=-1; // workspace query. Keep in mind that GESDD requires more memory than GESVD
+  /* note that optimal work size is returned in thresh */
+  GESVD("A", "A", (int *)&m, (int *)&m, NULL, (int *)&m, NULL, NULL, (int *)&m, NULL, (int *)&m, (LM_REAL *)&thresh, (int *)&worksz, &info);
+  //GESDD("A", (int *)&m, (int *)&m, NULL, (int *)&m, NULL, NULL, (int *)&m, NULL, (int *)&m, (LM_REAL *)&thresh, (int *)&worksz, NULL, &info);
+  worksz=(int)thresh;
+#else /* use minimum size */
+  worksz=5*m; // min worksize for GESVD
+  //worksz=m*(7*m+4); // min worksize for GESDD
+#endif
   iworksz=8*m;
   a_sz=m*m;
   u_sz=m*m; s_sz=m; vt_sz=m*m;
 
-  tot_sz=iworksz*sizeof(int) + (a_sz + u_sz + s_sz + vt_sz + worksz)*sizeof(LM_REAL);
+  tot_sz=(a_sz + u_sz + s_sz + vt_sz + worksz)*sizeof(LM_REAL) + iworksz*sizeof(int); /* should be arranged in that order for proper doubles alignment */
 
 #ifdef LINSOLVERS_RETAIN_MEMORY
   if(tot_sz>buf_sz){ /* insufficient memory, allocate a "big" memory chunk at once */
@@ -717,18 +915,18 @@ int info, rank, worksz, *iwork, iworksz;
     }
 #endif /* LINSOLVERS_RETAIN_MEMORY */
 
-  iwork=(int *)buf;
-  a=(LM_REAL *)(iwork+iworksz);
+  a=buf;
+  u=a+a_sz;
+  s=u+u_sz;
+  vt=s+s_sz;
+  work=vt+vt_sz;
+  iwork=(int *)(work+worksz);
+
   /* store A (column major!) into a */
   for(i=0; i<m; i++)
     for(j=0; j<m; j++)
       a[i+j*m]=A[i*m+j];
 
-  u=a + a_sz;
-  s=u+u_sz;
-  vt=s+s_sz;
-  work=vt+vt_sz;
-
   /* SVD decomposition of A */
   GESVD("A", "A", (int *)&m, (int *)&m, a, (int *)&m, s, u, (int *)&m, vt, (int *)&m, work, (int *)&worksz, &info);
   //GESDD("A", (int *)&m, (int *)&m, a, (int *)&m, s, u, (int *)&m, vt, (int *)&m, work, (int *)&worksz, iwork, &info);
@@ -753,15 +951,15 @@ int info, rank, worksz, *iwork, iworksz;
     LM_REAL aux;
 
     /* compute machine epsilon */
-    for(eps=CNST(1.0); aux=eps+CNST(1.0), aux-CNST(1.0)>0.0; eps*=CNST(0.5))
+    for(eps=LM_CNST(1.0); aux=eps+LM_CNST(1.0), aux-LM_CNST(1.0)>0.0; eps*=LM_CNST(0.5))
                                           ;
-    eps*=CNST(2.0);
+    eps*=LM_CNST(2.0);
   }
 
   /* compute the pseudoinverse in a */
 	for(i=0; i<a_sz; i++) a[i]=0.0; /* initialize to zero */
   for(rank=0, thresh=eps*s[0]; rank<m && s[rank]>thresh; rank++){
-    one_over_denom=CNST(1.0)/s[rank];
+    one_over_denom=LM_CNST(1.0)/s[rank];
 
     for(j=0; j<m; j++)
       for(i=0; i<m; i++)
@@ -782,22 +980,142 @@ int info, rank, worksz, *iwork, iworksz;
 	return 1;
 }
 
+/*
+ * This function returns the solution of Ax = b for a real symmetric matrix A
+ *
+ * The function is based on LDLT factorization with the pivoting
+ * strategy of Bunch and Kaufman:
+ * A is factored as L*D*L^T where L is lower triangular and
+ * D symmetric and block diagonal (aka spectral decomposition,
+ * Banachiewicz factorization, modified Cholesky factorization)
+ *
+ * A is mxm, b is mx1.
+ *
+ * The function returns 0 in case of error, 1 if successful
+ *
+ * This function is often called repetitively to solve problems of identical
+ * dimensions. To avoid repetitive malloc's and free's, allocated memory is
+ * retained between calls and free'd-malloc'ed when not of the appropriate size.
+ * A call with NULL as the first argument forces this memory to be released.
+ */
+int AX_EQ_B_BK(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m)
+{
+__STATIC__ LM_REAL *buf=NULL;
+__STATIC__ int buf_sz=0, nb=0;
+
+LM_REAL *a, *work;
+int a_sz, ipiv_sz, work_sz, tot_sz;
+int info, *ipiv, nrhs=1;
+   
+  if(!A)
+#ifdef LINSOLVERS_RETAIN_MEMORY
+  {
+    if(buf) free(buf);
+    buf=NULL;
+    buf_sz=0;
+
+    return 1;
+  }
+#else
+  return 1; /* NOP */
+#endif /* LINSOLVERS_RETAIN_MEMORY */
+
+  /* calculate required memory size */
+  ipiv_sz=m;
+  a_sz=m*m;
+  if(!nb){
+    LM_REAL tmp;
+
+    work_sz=-1; // workspace query; optimal size is returned in tmp
+    SYTRF("L", (int *)&m, NULL, (int *)&m, NULL, (LM_REAL *)&tmp, (int *)&work_sz, (int *)&info);
+    nb=((int)tmp)/m; // optimal worksize is m*nb
+  }
+  work_sz=(nb!=-1)? nb*m : 1;
+  tot_sz=(a_sz + work_sz)*sizeof(LM_REAL) + ipiv_sz*sizeof(int); /* should be arranged in that order for proper doubles alignment */
+
+#ifdef LINSOLVERS_RETAIN_MEMORY
+  if(tot_sz>buf_sz){ /* insufficient memory, allocate a "big" memory chunk at once */
+    if(buf) free(buf); /* free previously allocated memory */
+
+    buf_sz=tot_sz;
+    buf=(LM_REAL *)malloc(buf_sz);
+    if(!buf){
+      fprintf(stderr, RCAT("memory allocation in ", AX_EQ_B_BK) "() failed!\n");
+      exit(1);
+    }
+  }
+#else
+  buf_sz=tot_sz;
+  buf=(LM_REAL *)malloc(buf_sz);
+  if(!buf){
+    fprintf(stderr, RCAT("memory allocation in ", AX_EQ_B_BK) "() failed!\n");
+    exit(1);
+  }
+#endif /* LINSOLVERS_RETAIN_MEMORY */
+
+  a=buf;
+  work=a+a_sz;
+  ipiv=(int *)(work+work_sz);
+
+  /* store A into a and B into x; A is assumed to be symmetric, hence
+   * the column and row major order representations are the same
+   */
+  memcpy(a, A, a_sz*sizeof(LM_REAL));
+  memcpy(x, B, m*sizeof(LM_REAL));
+
+  /* LDLt factorization for A */
+	SYTRF("L", (int *)&m, a, (int *)&m, ipiv, work, (int *)&work_sz, (int *)&info);
+	if(info!=0){
+		if(info<0){
+      fprintf(stderr, RCAT(RCAT("LAPACK error: illegal value for argument %d of ", SYTRF) " in ", AX_EQ_B_BK) "()\n", -info);
+			exit(1);
+		}
+		else{
+      fprintf(stderr, RCAT(RCAT("LAPACK error: singular block diagonal matrix D for", SYTRF) " in ", AX_EQ_B_BK)"() [D(%d, %d) is zero]\n", info, info);
+#ifndef LINSOLVERS_RETAIN_MEMORY
+      free(buf);
+#endif
+
+			return 0;
+		}
+	}
+
+  /* solve the system with the computed factorization */
+  SYTRS("L", (int *)&m, (int *)&nrhs, a, (int *)&m, ipiv, x, (int *)&m, (int *)&info);
+  if(info<0){
+    fprintf(stderr, RCAT(RCAT("LAPACK error: illegal value for argument %d of ", SYTRS) " in ", AX_EQ_B_BK) "()\n", -info);
+    exit(1);
+	}
+
+#ifndef LINSOLVERS_RETAIN_MEMORY
+  free(buf);
+#endif
+
+	return 1;
+}
+
 /* undefine all. IT MUST REMAIN IN THIS POSITION IN FILE */
 #undef AX_EQ_B_QR
 #undef AX_EQ_B_QRLS
 #undef AX_EQ_B_CHOL
 #undef AX_EQ_B_LU
 #undef AX_EQ_B_SVD
+#undef AX_EQ_B_BK
+#undef AX_EQ_B_PLASMA_CHOL
 
 #undef GEQRF
 #undef ORGQR
 #undef TRTRS
 #undef POTF2
 #undef POTRF
+#undef POTRS
 #undef GETRF
 #undef GETRS
 #undef GESVD
 #undef GESDD
+#undef SYTRF
+#undef SYTRS
+#undef PLASMA_POSV
 
 #else // no LAPACK
 
@@ -812,8 +1130,7 @@ int info, rank, worksz, *iwork, iworksz;
  *
  * A is mxm, b is mx1
  *
- * The function returns 0 in case of error,
- * 1 if successfull
+ * The function returns 0 in case of error, 1 if successful
  *
  * This function is often called repetitively to solve problems of identical
  * dimensions. To avoid repetitive malloc's and free's, allocated memory is
@@ -829,19 +1146,24 @@ register int i, j, k;
 int *idx, maxi=-1, idx_sz, a_sz, work_sz, tot_sz;
 LM_REAL *a, *work, max, sum, tmp;
 
+    if(!A)
 #ifdef LINSOLVERS_RETAIN_MEMORY
-    if(!A){
+    {
       if(buf) free(buf);
+      buf=NULL;
       buf_sz=0;
+
       return 1;
     }
+#else
+    return 1; /* NOP */
 #endif /* LINSOLVERS_RETAIN_MEMORY */
    
   /* calculate required memory size */
   idx_sz=m;
   a_sz=m*m;
   work_sz=m;
-  tot_sz=idx_sz*sizeof(int) + (a_sz+work_sz)*sizeof(LM_REAL);
+  tot_sz=(a_sz+work_sz)*sizeof(LM_REAL) + idx_sz*sizeof(int); /* should be arranged in that order for proper doubles alignment */
 
 #ifdef LINSOLVERS_RETAIN_MEMORY
   if(tot_sz>buf_sz){ /* insufficient memory, allocate a "big" memory chunk at once */
@@ -863,23 +1185,13 @@ LM_REAL *a, *work, max, sum, tmp;
     }
 #endif /* LINSOLVERS_RETAIN_MEMORY */
 
-  idx=(int *)buf;
-  a=(LM_REAL *)(idx + idx_sz);
-  work=a + a_sz;
+  a=buf;
+  work=a+a_sz;
+  idx=(int *)(work+work_sz);
 
   /* avoid destroying A, B by copying them to a, x resp. */
-  for(i=0; i<m; ++i){ // B & 1st row of A
-    a[i]=A[i];
-    x[i]=B[i];
-  }
-  for(  ; i<a_sz; ++i) a[i]=A[i]; // copy A's remaining rows
-  /****
-  for(i=0; i<m; ++i){
-    for(j=0; j<m; ++j)
-      a[i*m+j]=A[i*m+j];
-    x[i]=B[i];
-  }
-  ****/
+  memcpy(a, A, a_sz*sizeof(LM_REAL));
+  memcpy(x, B, m*sizeof(LM_REAL));
 
   /* compute the LU decomposition of a row permutation of matrix a; the permutation itself is saved in idx[] */
 	for(i=0; i<m; ++i){
@@ -895,7 +1207,7 @@ LM_REAL *a, *work, max, sum, tmp;
 
         return 0;
       }
-		  work[i]=CNST(1.0)/max;
+		  work[i]=LM_CNST(1.0)/max;
 	}
 
 	for(j=0; j<m; ++j){
@@ -928,7 +1240,7 @@ LM_REAL *a, *work, max, sum, tmp;
 		if(a[j*m+j]==0.0)
       a[j*m+j]=LM_REAL_EPSILON;
 		if(j!=m-1){
-			tmp=CNST(1.0)/(a[j*m+j]);
+			tmp=LM_CNST(1.0)/(a[j*m+j]);
 			for(i=j+1; i<m; ++i)
         a[i*m+j]*=tmp;
 		}
