@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////
 // 
 //  Levenberg - Marquardt non-linear minimization algorithm
-//  Copyright (C) 2004  Manolis Lourakis (lourakis@ics.forth.gr)
+//  Copyright (C) 2004  Manolis Lourakis (lourakis at ics forth gr)
 //  Institute of Computer Science, Foundation for Research & Technology - Hellas
 //  Heraklion, Crete, Greece.
 //
@@ -28,9 +28,10 @@
 /* precision-specific definitions */
 #define LEVMAR_DER LM_ADD_PREFIX(levmar_der)
 #define LEVMAR_DIF LM_ADD_PREFIX(levmar_dif)
-#define FDIF_FORW_JAC_APPROX LM_ADD_PREFIX(fdif_forw_jac_approx)
-#define FDIF_CENT_JAC_APPROX LM_ADD_PREFIX(fdif_cent_jac_approx)
-#define TRANS_MAT_MAT_MULT LM_ADD_PREFIX(trans_mat_mat_mult)
+#define LEVMAR_FDIF_FORW_JAC_APPROX LM_ADD_PREFIX(levmar_fdif_forw_jac_approx)
+#define LEVMAR_FDIF_CENT_JAC_APPROX LM_ADD_PREFIX(levmar_fdif_cent_jac_approx)
+#define LEVMAR_TRANS_MAT_MAT_MULT LM_ADD_PREFIX(levmar_trans_mat_mat_mult)
+#define LEVMAR_L2NRMXMY LM_ADD_PREFIX(levmar_L2nrmxmy)
 #define LEVMAR_COVAR LM_ADD_PREFIX(levmar_covar)
 
 #ifdef HAVE_LAPACK
@@ -39,30 +40,35 @@
 #define AX_EQ_B_QR LM_ADD_PREFIX(Ax_eq_b_QR)
 #define AX_EQ_B_QRLS LM_ADD_PREFIX(Ax_eq_b_QRLS)
 #define AX_EQ_B_SVD LM_ADD_PREFIX(Ax_eq_b_SVD)
+#define AX_EQ_B_BK LM_ADD_PREFIX(Ax_eq_b_BK)
 #else
 #define AX_EQ_B_LU LM_ADD_PREFIX(Ax_eq_b_LU_noLapack)
 #endif /* HAVE_LAPACK */
 
+#ifdef HAVE_PLASMA
+#define AX_EQ_B_PLASMA_CHOL LM_ADD_PREFIX(Ax_eq_b_PLASMA_Chol)
+#endif
+
 /* 
  * This function seeks the parameter vector p that best describes the measurements vector x.
  * More precisely, given a vector function  func : R^m --> R^n with n>=m,
  * it finds p s.t. func(p) ~= x, i.e. the squared second order (i.e. L2) norm of
  * e=x-func(p) is minimized.
  *
- * This function requires an analytic jacobian. In case the latter is unavailable,
+ * This function requires an analytic Jacobian. In case the latter is unavailable,
  * use LEVMAR_DIF() bellow
  *
- * Returns the number of iterations (>=0) if successfull, -1 if failed
+ * Returns the number of iterations (>=0) if successful, LM_ERROR if failed
  *
- * For more details, see H.B. Nielsen's (http://www.imm.dtu.dk/~hbn) IMM/DTU
- * tutorial at http://www.imm.dtu.dk/courses/02611/nllsq.pdf
+ * For more details, see K. Madsen, H.B. Nielsen and O. Tingleff's lecture notes on 
+ * non-linear least squares at http://www.imm.dtu.dk/pubdb/views/edoc_download.php/3215/pdf/imm3215.pdf
  */
 
 int LEVMAR_DER(
   void (*func)(LM_REAL *p, LM_REAL *hx, int m, int n, void *adata), /* functional relation describing measurements. A p \in R^m yields a \hat{x} \in  R^n */
-  void (*jacf)(LM_REAL *p, LM_REAL *j, int m, int n, void *adata),  /* function to evaluate the jacobian \part x / \part p */ 
+  void (*jacf)(LM_REAL *p, LM_REAL *j, int m, int n, void *adata),  /* function to evaluate the Jacobian \part x / \part p */ 
   LM_REAL *p,         /* I/O: initial parameter estimates. On output has the estimated solution */
-  LM_REAL *x,         /* I: measurement vector */
+  LM_REAL *x,         /* I: measurement vector. NULL implies a zero vector */
   int m,              /* I: parameter vector dimension (i.e. #unknowns) */
   int n,              /* I: measurement vector dimension */
   int itmax,          /* I: maximum number of iterations */
@@ -80,10 +86,12 @@ int LEVMAR_DER(
                       *                                 4 - singular matrix. Restart from current p with increased mu 
                       *                                 5 - no further error reduction is possible. Restart with increased mu
                       *                                 6 - stopped by small ||e||_2
+                      *                                 7 - stopped by invalid (i.e. NaN or Inf) "func" values. This is a user error
                       * info[7]= # function evaluations
-                      * info[8]= # jacobian evaluations
+                      * info[8]= # Jacobian evaluations
+                      * info[9]= # linear systems solved, i.e. # attempts for reducing error
                       */
-  LM_REAL *work,     /* working memory, allocate if NULL */
+  LM_REAL *work,     /* working memory at least LM_DER_WORKSZ() reals large, allocated if NULL */
   LM_REAL *covar,    /* O: Covariance matrix corresponding to LS solution; mxm. Set to NULL if not needed. */
   void *adata)       /* pointer to possibly additional data, passed uninterpreted to func & jacf.
                       * Set to NULL if not needed
@@ -107,20 +115,21 @@ LM_REAL p_eL2, jacTe_inf, pDp_eL2; /* ||e(p)||_2, ||J^T e||_inf, ||e(p+Dp)||_2 *
 LM_REAL p_L2, Dp_L2=LM_REAL_MAX, dF, dL;
 LM_REAL tau, eps1, eps2, eps2_sq, eps3;
 LM_REAL init_p_eL2;
-int nu=2, nu2, stop, nfev, njev=0;
+int nu=2, nu2, stop=0, nfev, njev=0, nlss=0;
 const int nm=n*m;
+int (*linsolver)(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m)=NULL;
 
   mu=jacTe_inf=0.0; /* -Wall */
 
   if(n<m){
     fprintf(stderr, LCAT(LEVMAR_DER, "(): cannot solve a problem with fewer measurements [%d] than unknowns [%d]\n"), n, m);
-    return -1;
+    return LM_ERROR;
   }
 
   if(!jacf){
-    fprintf(stderr, RCAT("No function specified for computing the jacobian in ", LEVMAR_DER)
+    fprintf(stderr, RCAT("No function specified for computing the Jacobian in ", LEVMAR_DER)
         RCAT("().\nIf no such function is available, use ", LEVMAR_DIF) RCAT("() rather than ", LEVMAR_DER) "()\n");
-    return -1;
+    return LM_ERROR;
   }
 
   if(opts){
@@ -131,11 +140,11 @@ const int nm=n*m;
     eps3=opts[3];
   }
   else{ // use default values
-	  tau=CNST(LM_INIT_MU);
-	  eps1=CNST(LM_STOP_THRESH);
-	  eps2=CNST(LM_STOP_THRESH);
-	  eps2_sq=CNST(LM_STOP_THRESH)*CNST(LM_STOP_THRESH);
-    eps3=CNST(LM_STOP_THRESH);
+	  tau=LM_CNST(LM_INIT_MU);
+	  eps1=LM_CNST(LM_STOP_THRESH);
+	  eps2=LM_CNST(LM_STOP_THRESH);
+	  eps2_sq=LM_CNST(LM_STOP_THRESH)*LM_CNST(LM_STOP_THRESH);
+    eps3=LM_CNST(LM_STOP_THRESH);
   }
 
   if(!work){
@@ -143,7 +152,7 @@ const int nm=n*m;
     work=(LM_REAL *)malloc(worksz*sizeof(LM_REAL)); /* allocate a big chunk in one step */
     if(!work){
       fprintf(stderr, LCAT(LEVMAR_DER, "(): memory allocation request failed\n"));
-      return -1;
+      return LM_ERROR;
     }
     freework=1;
   }
@@ -160,13 +169,19 @@ const int nm=n*m;
 
   /* compute e=x - f(p) and its L2 norm */
   (*func)(p, hx, m, n, adata); nfev=1;
+  /* ### e=x-hx, p_eL2=||e|| */
+#if 1
+  p_eL2=LEVMAR_L2NRMXMY(e, x, hx, n);  
+#else
   for(i=0, p_eL2=0.0; i<n; ++i){
     e[i]=tmp=x[i]-hx[i];
     p_eL2+=tmp*tmp;
   }
+#endif
   init_p_eL2=p_eL2;
+  if(!LM_FINITE(p_eL2)) stop=7;
 
-  for(k=stop=0; k<itmax && !stop; ++k){
+  for(k=0; k<itmax && !stop; ++k){
     /* Note that p and e have been updated at a previous iteration */
 
     if(p_eL2<=eps3){ /* error is small */
@@ -174,8 +189,8 @@ const int nm=n*m;
       break;
     }
 
-    /* Compute the jacobian J at p,  J^T J,  J^T e,  ||J^T e||_inf and ||p||^2.
-     * Since J^T J is symmetric, its computation can be speeded up by computing
+    /* Compute the Jacobian J at p,  J^T J,  J^T e,  ||J^T e||_inf and ||p||^2.
+     * Since J^T J is symmetric, its computation can be sped up by computing
      * only its upper triangular part and copying it to the lower part
      */
 
@@ -183,43 +198,56 @@ const int nm=n*m;
 
     /* J^T J, J^T e */
     if(nm<__BLOCKSZ__SQ){ // this is a small problem
-      /* This is the straightforward way to compute J^T J, J^T e. However, due to
-       * its noncontinuous memory access pattern, it incures many cache misses when
-       * applied to large minimization problems (i.e. problems involving a large
-       * number of free variables and measurements), in which J is too large to
-       * fit in the L1 cache. For such problems, a cache-efficient blocking scheme
-       * is preferable.
+      /* J^T*J_ij = \sum_l J^T_il * J_lj = \sum_l J_li * J_lj.
+       * Thus, the product J^T J can be computed using an outer loop for
+       * l that adds J_li*J_lj to each element ij of the result. Note that
+       * with this scheme, the accesses to J and JtJ are always along rows,
+       * therefore induces less cache misses compared to the straightforward
+       * algorithm for computing the product (i.e., l loop is innermost one).
+       * A similar scheme applies to the computation of J^T e.
+       * However, for large minimization problems (i.e., involving a large number
+       * of unknowns and measurements) for which J/J^T J rows are too large to
+       * fit in the L1 cache, even this scheme incures many cache misses. In
+       * such cases, a cache-efficient blocking scheme is preferable.
        *
        * Thanks to John Nitao of Lawrence Livermore Lab for pointing out this
        * performance problem.
        *
-       * On the other hand, the straightforward algorithm is faster on small
+       * Note that the non-blocking algorithm is faster on small
        * problems since in this case it avoids the overheads of blocking. 
        */
 
-      for(i=0; i<m; ++i){
-        for(j=i; j<m; ++j){
-          int lm;
+      /* looping downwards saves a few computations */
+      register int l;
+      register LM_REAL alpha, *jaclm, *jacTjacim;
 
-          for(l=0, tmp=0.0; l<n; ++l){
-            lm=l*m;
-            tmp+=jac[lm+i]*jac[lm+j];
-          }
+      for(i=m*m; i-->0; )
+        jacTjac[i]=0.0;
+      for(i=m; i-->0; )
+        jacTe[i]=0.0;
 
-		      /* store tmp in the corresponding upper and lower part elements */
-          jacTjac[i*m+j]=jacTjac[j*m+i]=tmp;
+      for(l=n; l-->0; ){
+        jaclm=jac+l*m;
+        for(i=m; i-->0; ){
+          jacTjacim=jacTjac+i*m;
+          alpha=jaclm[i]; //jac[l*m+i];
+          for(j=i+1; j-->0; ) /* j<=i computes lower triangular part only */
+            jacTjacim[j]+=jaclm[j]*alpha; //jacTjac[i*m+j]+=jac[l*m+j]*alpha
+
+          /* J^T e */
+          jacTe[i]+=alpha*e[l];
         }
-
-        /* J^T e */
-        for(l=0, tmp=0.0; l<n; ++l)
-          tmp+=jac[l*m+i]*e[l];
-        jacTe[i]=tmp;
       }
+
+      for(i=m; i-->0; ) /* copy to upper part */
+        for(j=i+1; j<m; ++j)
+          jacTjac[i*m+j]=jacTjac[j*m+i];
+
     }
     else{ // this is a large problem
       /* Cache efficient computation of J^T J based on blocking
        */
-      TRANS_MAT_MAT_MULT(jac, jacTjac, n, m);
+      LEVMAR_TRANS_MAT_MAT_MULT(jac, jacTjac, n, m);
 
       /* cache efficient computation of J^T e */
       for(i=0; i<m; ++i)
@@ -243,8 +271,8 @@ const int nm=n*m;
     //p_L2=sqrt(p_L2);
 
 #if 0
-if(!(k%10)){
-  printf("Iter: %d, estimate: ", k);
+if(!(k%100)){
+  printf("Current estimate: ");
   for(i=0; i<m; ++i)
     printf("%.9g ", p[i]);
   printf("-- errors %.9g %0.9g\n", jacTe_inf, p_eL2);
@@ -273,20 +301,26 @@ if(!(k%10)){
 
       /* solve augmented equations */
 #ifdef HAVE_LAPACK
-      /* 5 alternatives are available: LU, Cholesky, 2 variants of QR decomposition and SVD.
-       * Cholesky is the fastest but might be inaccurate; QR is slower but more accurate;
-       * SVD is the slowest but most accurate; LU offers a tradeoff between accuracy and speed
+      /* 7 alternatives are available: LU, Cholesky + Cholesky with PLASMA, LDLt, 2 variants of QR decomposition and SVD.
+       * For matrices with dimensions of at least a few hundreds, the PLASMA implementation of Cholesky is the fastest.
+       * From the serial solvers, Cholesky is the fastest but might occasionally be inapplicable due to numerical round-off;
+       * QR is slower but more robust; SVD is the slowest but most robust; LU is quite robust but
+       * slower than LDLt; LDLt offers a good tradeoff between robustness and speed
        */
 
-      issolved=AX_EQ_B_LU(jacTjac, jacTe, Dp, m);
-      //issolved=AX_EQ_B_CHOL(jacTjac, jacTe, Dp, m);
-      //issolved=AX_EQ_B_QR(jacTjac, jacTe, Dp, m);
-      //issolved=AX_EQ_B_QRLS(jacTjac, jacTe, Dp, m, m);
-      //issolved=AX_EQ_B_SVD(jacTjac, jacTe, Dp, m);
+      issolved=AX_EQ_B_BK(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_BK;
+      //issolved=AX_EQ_B_LU(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_LU;
+      //issolved=AX_EQ_B_CHOL(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_CHOL;
+#ifdef HAVE_PLASMA
+      //issolved=AX_EQ_B_PLASMA_CHOL(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_PLASMA_CHOL;
+#endif
+      //issolved=AX_EQ_B_QR(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_QR;
+      //issolved=AX_EQ_B_QRLS(jacTjac, jacTe, Dp, m, m); ++nlss; linsolver=(int (*)(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m))AX_EQ_B_QRLS;
+      //issolved=AX_EQ_B_SVD(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_SVD;
 
 #else
       /* use the LU included with levmar */
-      issolved=AX_EQ_B_LU(jacTjac, jacTe, Dp, m);
+      issolved=AX_EQ_B_LU(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_LU;
 #endif /* HAVE_LAPACK */
 
       if(issolved){
@@ -303,17 +337,30 @@ if(!(k%10)){
           break;
         }
 
-       if(Dp_L2>=(p_L2+eps2)/(CNST(EPSILON)*CNST(EPSILON))){ /* almost singular */
-       //if(Dp_L2>=(p_L2+eps2)/CNST(EPSILON)){ /* almost singular */
+       if(Dp_L2>=(p_L2+eps2)/(LM_CNST(EPSILON)*LM_CNST(EPSILON))){ /* almost singular */
+       //if(Dp_L2>=(p_L2+eps2)/LM_CNST(EPSILON)){ /* almost singular */
          stop=4;
          break;
        }
 
         (*func)(pDp, hx, m, n, adata); ++nfev; /* evaluate function at p + Dp */
-        for(i=0, pDp_eL2=0.0; i<n; ++i){ /* compute ||e(pDp)||_2 */
+        /* compute ||e(pDp)||_2 */
+        /* ### hx=x-hx, pDp_eL2=||hx|| */
+#if 1
+        pDp_eL2=LEVMAR_L2NRMXMY(hx, x, hx, n);
+#else
+        for(i=0, pDp_eL2=0.0; i<n; ++i){
           hx[i]=tmp=x[i]-hx[i];
           pDp_eL2+=tmp*tmp;
         }
+#endif
+        if(!LM_FINITE(pDp_eL2)){ /* sum of squares is not finite, most probably due to a user error.
+                                  * This check makes sure that the inner loop does not run indefinitely.
+                                  * Thanks to Steve Danauskas for reporting such cases
+                                  */
+          stop=7;
+          break;
+        }
 
         for(i=0, dL=0.0; i<m; ++i)
           dL+=Dp[i]*(mu*Dp[i]+jacTe[i]);
@@ -321,9 +368,9 @@ if(!(k%10)){
         dF=p_eL2-pDp_eL2;
 
         if(dL>0.0 && dF>0.0){ /* reduction in error, increment is accepted */
-          tmp=(CNST(2.0)*dF/dL-CNST(1.0));
-          tmp=CNST(1.0)-tmp*tmp*tmp;
-          mu=mu*( (tmp>=CNST(ONE_THIRD))? tmp : CNST(ONE_THIRD) );
+          tmp=(LM_CNST(2.0)*dF/dL-LM_CNST(1.0));
+          tmp=LM_CNST(1.0)-tmp*tmp*tmp;
+          mu=mu*( (tmp>=LM_CNST(ONE_THIRD))? tmp : LM_CNST(ONE_THIRD) );
           nu=2;
 
           for(i=0 ; i<m; ++i) /* update p's estimate */
@@ -370,6 +417,7 @@ if(!(k%10)){
     info[6]=(LM_REAL)stop;
     info[7]=(LM_REAL)nfev;
     info[8]=(LM_REAL)njev;
+    info[9]=(LM_REAL)nlss;
   }
 
   /* covariance matrix */
@@ -379,25 +427,29 @@ if(!(k%10)){
 
   if(freework) free(work);
 
-  return (stop!=4)?  k : -1;
+#ifdef LINSOLVERS_RETAIN_MEMORY
+  if(linsolver) (*linsolver)(NULL, NULL, NULL, 0);
+#endif
+
+  return (stop!=4 && stop!=7)?  k : LM_ERROR;
 }
 
 
-/* Secant version of the LEVMAR_DER() function above: the jacobian is approximated with 
+/* Secant version of the LEVMAR_DER() function above: the Jacobian is approximated with 
  * the aid of finite differences (forward or central, see the comment for the opts argument)
  */
 int LEVMAR_DIF(
   void (*func)(LM_REAL *p, LM_REAL *hx, int m, int n, void *adata), /* functional relation describing measurements. A p \in R^m yields a \hat{x} \in  R^n */
-  int (*visf)(LM_REAL *p, LM_REAL *hx, int m, int n, int iter, LM_REAL p_eL2, void *adata), /* visualisation function, can be used to print optimisation progress. If 0 is returned, the optimisation is stopped, and the current estimate will be used. */
+  int(*visf)(LM_REAL *p, LM_REAL *hx, int m, int n, int iter, LM_REAL p_eL2, void *adata), /* visualisation function, can be used to print optimisation progress. If 0 is returned, the optimisation is stopped, and the current estimate will be used. */
   LM_REAL *p,         /* I/O: initial parameter estimates. On output has the estimated solution */
-  LM_REAL *x,         /* I: measurement vector */
+  LM_REAL *x,         /* I: measurement vector. NULL implies a zero vector */
   int m,              /* I: parameter vector dimension (i.e. #unknowns) */
   int n,              /* I: measurement vector dimension */
   int itmax,          /* I: maximum number of iterations */
   LM_REAL opts[5],    /* I: opts[0-4] = minim. options [\mu, \epsilon1, \epsilon2, \epsilon3, \delta]. Respectively the
                        * scale factor for initial \mu, stopping thresholds for ||J^T e||_inf, ||Dp||_2 and ||e||_2 and
-                       * the step used in difference approximation to the jacobian. Set to NULL for defaults to be used.
-                       * If \delta<0, the jacobian is approximated with central differences which are more accurate
+                       * the step used in difference approximation to the Jacobian. Set to NULL for defaults to be used.
+                       * If \delta<0, the Jacobian is approximated with central differences which are more accurate
                        * (but slower!) compared to the forward differences employed by default. 
                        */
   LM_REAL info[LM_INFO_SZ],
@@ -411,11 +463,12 @@ int LEVMAR_DIF(
                       *                                 4 - singular matrix. Restart from current p with increased mu 
                       *                                 5 - no further error reduction is possible. Restart with increased mu
                       *                                 6 - stopped by small ||e||_2
-                      *                                 7 - stopped by user
+                      *                                 7 - stopped by invalid (i.e. NaN or Inf) "func" values. This is a user error
                       * info[7]= # function evaluations
-                      * info[8]= # jacobian evaluations
+                      * info[8]= # Jacobian evaluations
+                      * info[9]= # linear systems solved, i.e. # attempts for reducing error
                       */
-  LM_REAL *work,     /* working memory, allocate if NULL */
+  LM_REAL *work,     /* working memory at least LM_DIF_WORKSZ() reals large, allocated if NULL */
   LM_REAL *covar,    /* O: Covariance matrix corresponding to LS solution; mxm. Set to NULL if not needed. */
   void *adata)       /* pointer to possibly additional data, passed uninterpreted to func.
                       * Set to NULL if not needed
@@ -432,10 +485,10 @@ LM_REAL *e,          /* nx1 */
        *Dp,         /* mx1 */
    *diag_jacTjac,   /* diagonal of J^T J, mx1 */
        *pDp,        /* p + Dp, mx1 */
-       *wrk;        /* nx1 */
+       *wrk,        /* nx1 */
+       *wrk2;       /* nx1, used only for holding a temporary e vector and when differentiating with central differences */
 
 int using_ffdif=1;
-LM_REAL *wrk2=NULL; /* nx1, used for differentiating with central differences only */
 
 register LM_REAL mu,  /* damping constant */
                 tmp; /* mainly used in matrix & vector multiplications */
@@ -443,15 +496,16 @@ LM_REAL p_eL2, jacTe_inf, pDp_eL2; /* ||e(p)||_2, ||J^T e||_inf, ||e(p+Dp)||_2 *
 LM_REAL p_L2, Dp_L2=LM_REAL_MAX, dF, dL;
 LM_REAL tau, eps1, eps2, eps2_sq, eps3, delta;
 LM_REAL init_p_eL2;
-int nu, nu2, stop, nfev, njap=0, K=(m>=10)? m: 10, updjac, updp=1, newjac;
+int nu, nu2, stop=0, nfev, njap=0, nlss=0, K=(m>=10)? m: 10, updjac, updp=1, newjac;
 const int nm=n*m;
+int (*linsolver)(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m)=NULL;
 
   mu=jacTe_inf=p_L2=0.0; /* -Wall */
-  stop=updjac=newjac=0; /* -Wall */
+  updjac=newjac=0; /* -Wall */
 
   if(n<m){
     fprintf(stderr, LCAT(LEVMAR_DIF, "(): cannot solve a problem with fewer measurements [%d] than unknowns [%d]\n"), n, m);
-    return -1;
+    return LM_ERROR;
   }
 
   if(opts){
@@ -464,29 +518,23 @@ const int nm=n*m;
     if(delta<0.0){
       delta=-delta; /* make positive */
       using_ffdif=0; /* use central differencing */
-      wrk2=(LM_REAL *)malloc(n*sizeof(LM_REAL));
-      if(!wrk2){
-        fprintf(stderr, LCAT(LEVMAR_DIF, "(): memory allocation request for 'wrk2' failed\n"));
-        return -1;
-      }
     }
   }
   else{ // use default values
-	  tau=CNST(LM_INIT_MU);
-	  eps1=CNST(LM_STOP_THRESH);
-	  eps2=CNST(LM_STOP_THRESH);
-	  eps2_sq=CNST(LM_STOP_THRESH)*CNST(LM_STOP_THRESH);
-    eps3=CNST(LM_STOP_THRESH);
-	  delta=CNST(LM_DIFF_DELTA);
+	  tau=LM_CNST(LM_INIT_MU);
+	  eps1=LM_CNST(LM_STOP_THRESH);
+	  eps2=LM_CNST(LM_STOP_THRESH);
+	  eps2_sq=LM_CNST(LM_STOP_THRESH)*LM_CNST(LM_STOP_THRESH);
+    eps3=LM_CNST(LM_STOP_THRESH);
+	  delta=LM_CNST(LM_DIFF_DELTA);
   }
 
   if(!work){
-    worksz=LM_DIF_WORKSZ(m, n); //3*n+4*m + n*m + m*m;
+    worksz=LM_DIF_WORKSZ(m, n); //4*n+4*m + n*m + m*m;
     work=(LM_REAL *)malloc(worksz*sizeof(LM_REAL)); /* allocate a big chunk in one step */
     if(!work){
-      if(wrk2) free(wrk2);
       fprintf(stderr, LCAT(LEVMAR_DIF, "(): memory allocation request failed\n"));
-      return -1;
+      return LM_ERROR;
     }
     freework=1;
   }
@@ -501,18 +549,25 @@ const int nm=n*m;
   diag_jacTjac=Dp + m;
   pDp=diag_jacTjac + m;
   wrk=pDp + m;
+  wrk2=wrk + n;
 
   /* compute e=x - f(p) and its L2 norm */
   (*func)(p, hx, m, n, adata); nfev=1;
+  /* ### e=x-hx, p_eL2=||e|| */
+#if 1
+  p_eL2=LEVMAR_L2NRMXMY(e, x, hx, n);
+#else
   for(i=0, p_eL2=0.0; i<n; ++i){
     e[i]=tmp=x[i]-hx[i];
     p_eL2+=tmp*tmp;
   }
+#endif
   init_p_eL2=p_eL2;
+  if(!LM_FINITE(p_eL2)) stop=7;
 
   nu=20; /* force computation of J */
 
-  for(k=0; k<itmax; ++k){
+  for(k=0; k<itmax && !stop; ++k){
     /* Note that p and e have been updated at a previous iteration */
 
     if(p_eL2<=eps3){ /* error is small */
@@ -520,63 +575,75 @@ const int nm=n*m;
       break;
     }
 
-    /* Compute the jacobian J at p,  J^T J,  J^T e,  ||J^T e||_inf and ||p||^2.
+    /* Compute the Jacobian J at p,  J^T J,  J^T e,  ||J^T e||_inf and ||p||^2.
      * The symmetry of J^T J is again exploited for speed
      */
 
     if((updp && nu>16) || updjac==K){ /* compute difference approximation to J */
       if(using_ffdif){ /* use forward differences */
-        FDIF_FORW_JAC_APPROX(func, p, hx, wrk, delta, jac, m, n, adata);
+        LEVMAR_FDIF_FORW_JAC_APPROX(func, p, hx, wrk, delta, jac, m, n, adata);
         ++njap; nfev+=m;
       }
       else{ /* use central differences */
-        FDIF_CENT_JAC_APPROX(func, p, wrk, wrk2, delta, jac, m, n, adata);
+        LEVMAR_FDIF_CENT_JAC_APPROX(func, p, wrk, wrk2, delta, jac, m, n, adata);
         ++njap; nfev+=2*m;
       }
       nu=2; updjac=0; updp=0; newjac=1;
     }
 
-    if(newjac){ /* jacobian has changed, recompute J^T J, J^t e, etc */
+    if(newjac){ /* Jacobian has changed, recompute J^T J, J^t e, etc */
       newjac=0;
 
       /* J^T J, J^T e */
       if(nm<=__BLOCKSZ__SQ){ // this is a small problem
-        /* This is the straightforward way to compute J^T J, J^T e. However, due to
-         * its noncontinuous memory access pattern, it incures many cache misses when
-         * applied to large minimization problems (i.e. problems involving a large
-         * number of free variables and measurements), in which J is too large to
-         * fit in the L1 cache. For such problems, a cache-efficient blocking scheme
-         * is preferable.
+        /* J^T*J_ij = \sum_l J^T_il * J_lj = \sum_l J_li * J_lj.
+         * Thus, the product J^T J can be computed using an outer loop for
+         * l that adds J_li*J_lj to each element ij of the result. Note that
+         * with this scheme, the accesses to J and JtJ are always along rows,
+         * therefore induces less cache misses compared to the straightforward
+         * algorithm for computing the product (i.e., l loop is innermost one).
+         * A similar scheme applies to the computation of J^T e.
+         * However, for large minimization problems (i.e., involving a large number
+         * of unknowns and measurements) for which J/J^T J rows are too large to
+         * fit in the L1 cache, even this scheme incures many cache misses. In
+         * such cases, a cache-efficient blocking scheme is preferable.
          *
          * Thanks to John Nitao of Lawrence Livermore Lab for pointing out this
          * performance problem.
          *
-         * On the other hand, the straightforward algorithm is faster on small
+         * Note that the non-blocking algorithm is faster on small
          * problems since in this case it avoids the overheads of blocking. 
          */
-      
-        for(i=0; i<m; ++i){
-          for(j=i; j<m; ++j){
-            int lm;
+        register int l;
+        register LM_REAL alpha, *jaclm, *jacTjacim;
 
-            for(l=0, tmp=0.0; l<n; ++l){
-              lm=l*m;
-              tmp+=jac[lm+i]*jac[lm+j];
-            }
+        /* looping downwards saves a few computations */
+        for(i=m*m; i-->0; )
+          jacTjac[i]=0.0;
+        for(i=m; i-->0; )
+          jacTe[i]=0.0;
 
-            jacTjac[i*m+j]=jacTjac[j*m+i]=tmp;
+        for(l=n; l-->0; ){
+          jaclm=jac+l*m;
+          for(i=m; i-->0; ){
+            jacTjacim=jacTjac+i*m;
+            alpha=jaclm[i]; //jac[l*m+i];
+            for(j=i+1; j-->0; ) /* j<=i computes lower triangular part only */
+              jacTjacim[j]+=jaclm[j]*alpha; //jacTjac[i*m+j]+=jac[l*m+j]*alpha
+
+            /* J^T e */
+            jacTe[i]+=alpha*e[l];
           }
-
-          /* J^T e */
-          for(l=0, tmp=0.0; l<n; ++l)
-            tmp+=jac[l*m+i]*e[l];
-          jacTe[i]=tmp;
         }
+
+        for(i=m; i-->0; ) /* copy to upper part */
+          for(j=i+1; j<m; ++j)
+            jacTjac[i*m+j]=jacTjac[j*m+i];
       }
       else{ // this is a large problem
         /* Cache efficient computation of J^T J based on blocking
          */
-        TRANS_MAT_MAT_MULT(jac, jacTjac, n, m);
+        LEVMAR_TRANS_MAT_MAT_MULT(jac, jacTjac, n, m);
 
         /* cache efficient computation of J^T e */
         for(i=0; i<m; ++i)
@@ -608,8 +675,8 @@ const int nm=n*m;
         }
     }
 #if 0
-if(!(k%10)){
-    printf("Iter: %d, estimate: ", k);
+if(!(k%100)){
+  printf("Current estimate: ");
   for(i=0; i<m; ++i)
     printf("%.9g ", p[i]);
   printf("-- errors %.9g %0.9g\n", jacTe_inf, p_eL2);
@@ -638,19 +705,25 @@ if(!(k%10)){
 
     /* solve augmented equations */
 #ifdef HAVE_LAPACK
-    /* 5 alternatives are available: LU, Cholesky, 2 variants of QR decomposition and SVD.
-     * Cholesky is the fastest but might be inaccurate; QR is slower but more accurate;
-     * SVD is the slowest but most accurate; LU offers a tradeoff between accuracy and speed
+    /* 7 alternatives are available: LU, Cholesky + Cholesky with PLASMA, LDLt, 2 variants of QR decomposition and SVD.
+     * For matrices with dimensions of at least a few hundreds, the PLASMA implementation of Cholesky is the fastest.
+     * From the serial solvers, Cholesky is the fastest but might occasionally be inapplicable due to numerical round-off;
+     * QR is slower but more robust; SVD is the slowest but most robust; LU is quite robust but
+     * slower than LDLt; LDLt offers a good tradeoff between robustness and speed
      */
 
-    issolved=AX_EQ_B_LU(jacTjac, jacTe, Dp, m);
-    //issolved=AX_EQ_B_CHOL(jacTjac, jacTe, Dp, m);
-    //issolved=AX_EQ_B_QR(jacTjac, jacTe, Dp, m);
-    //issolved=AX_EQ_B_QRLS(jacTjac, jacTe, Dp, m, m);
-    //issolved=AX_EQ_B_SVD(jacTjac, jacTe, Dp, m);
+    issolved=AX_EQ_B_BK(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_BK;
+    //issolved=AX_EQ_B_LU(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_LU;
+    //issolved=AX_EQ_B_CHOL(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_CHOL;
+#ifdef HAVE_PLASMA
+    //issolved=AX_EQ_B_PLASMA_CHOL(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_PLASMA_CHOL;
+#endif
+    //issolved=AX_EQ_B_QR(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_QR;
+    //issolved=AX_EQ_B_QRLS(jacTjac, jacTe, Dp, m, m); ++nlss; linsolver=(int (*)(LM_REAL *A, LM_REAL *B, LM_REAL *x, int m))AX_EQ_B_QRLS;
+    //issolved=AX_EQ_B_SVD(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_SVD;
 #else
     /* use the LU included with levmar */
-    issolved=AX_EQ_B_LU(jacTjac, jacTe, Dp, m);
+    issolved=AX_EQ_B_LU(jacTjac, jacTe, Dp, m); ++nlss; linsolver=AX_EQ_B_LU;
 #endif /* HAVE_LAPACK */
 
     if(issolved){
@@ -667,17 +740,31 @@ if(!(k%10)){
         break;
       }
 
-      if(Dp_L2>=(p_L2+eps2)/(CNST(EPSILON)*CNST(EPSILON))){ /* almost singular */
-      //if(Dp_L2>=(p_L2+eps2)/CNST(EPSILON)){ /* almost singular */
+      if(Dp_L2>=(p_L2+eps2)/(LM_CNST(EPSILON)*LM_CNST(EPSILON))){ /* almost singular */
+      //if(Dp_L2>=(p_L2+eps2)/LM_CNST(EPSILON)){ /* almost singular */
         stop=4;
         break;
       }
 
       (*func)(pDp, wrk, m, n, adata); ++nfev; /* evaluate function at p + Dp */
-      for(i=0, pDp_eL2=0.0; i<n; ++i){ /* compute ||e(pDp)||_2 */
-        tmp=x[i]-wrk[i];
+      /* compute ||e(pDp)||_2 */
+      /* ### wrk2=x-wrk, pDp_eL2=||wrk2|| */
+#if 1
+      pDp_eL2=LEVMAR_L2NRMXMY(wrk2, x, wrk, n);
+#else
+      for(i=0, pDp_eL2=0.0; i<n; ++i){
+        wrk2[i]=tmp=x[i]-wrk[i];
         pDp_eL2+=tmp*tmp;
       }
+#endif
+      if(!LM_FINITE(pDp_eL2)){ /* sum of squares is not finite, most probably due to a user error.
+                                * This check makes sure that the loop terminates early in the case
+                                * of invalid input. Thanks to Steve Danauskas for suggesting it
+                                */
+
+        stop=7;
+        break;
+      }
 
       dF=p_eL2-pDp_eL2;
       if(updp || dF>0){ /* update jac */
@@ -696,17 +783,16 @@ if(!(k%10)){
         dL+=Dp[i]*(mu*Dp[i]+jacTe[i]);
 
       if(dL>0.0 && dF>0.0){ /* reduction in error, increment is accepted */
-        dF=(CNST(2.0)*dF/dL-CNST(1.0));
-        tmp=dF*dF*dF;
-        tmp=CNST(1.0)-tmp*tmp*dF;
-        mu=mu*( (tmp>=CNST(ONE_THIRD))? tmp : CNST(ONE_THIRD) );
+        tmp=(LM_CNST(2.0)*dF/dL-LM_CNST(1.0));
+        tmp=LM_CNST(1.0)-tmp*tmp*tmp;
+        mu=mu*( (tmp>=LM_CNST(ONE_THIRD))? tmp : LM_CNST(ONE_THIRD) );
         nu=2;
 
         for(i=0 ; i<m; ++i) /* update p's estimate */
           p[i]=pDp[i];
 
         for(i=0; i<n; ++i){ /* update e, hx and ||e||_2 */
-          e[i]=x[i]-wrk[i];
+          e[i]=wrk2[i]; //x[i]-wrk[i];
           hx[i]=wrk[i];
         }
         p_eL2=pDp_eL2;
@@ -748,6 +834,7 @@ if(!(k%10)){
     info[6]=(LM_REAL)stop;
     info[7]=(LM_REAL)nfev;
     info[8]=(LM_REAL)njap;
+    info[9]=(LM_REAL)nlss;
   }
 
   /* covariance matrix */
@@ -758,20 +845,25 @@ if(!(k%10)){
                                                                
   if(freework) free(work);
 
-  if(wrk2) free(wrk2);
+#ifdef LINSOLVERS_RETAIN_MEMORY
+  if(linsolver) (*linsolver)(NULL, NULL, NULL, 0);
+#endif
 
-  return (stop!=4)?  k : -1;
+  return (stop!=4 && stop!=7)?  k : LM_ERROR;
 }
 
 /* undefine everything. THIS MUST REMAIN AT THE END OF THE FILE */
 #undef LEVMAR_DER
 #undef LEVMAR_DIF
-#undef FDIF_FORW_JAC_APPROX
-#undef FDIF_CENT_JAC_APPROX
+#undef LEVMAR_FDIF_FORW_JAC_APPROX
+#undef LEVMAR_FDIF_CENT_JAC_APPROX
 #undef LEVMAR_COVAR
-#undef TRANS_MAT_MAT_MULT
+#undef LEVMAR_TRANS_MAT_MAT_MULT
+#undef LEVMAR_L2NRMXMY
 #undef AX_EQ_B_LU
 #undef AX_EQ_B_CHOL
+#undef AX_EQ_B_PLASMA_CHOL
 #undef AX_EQ_B_QR
 #undef AX_EQ_B_QRLS
 #undef AX_EQ_B_SVD
+#undef AX_EQ_B_BK
