@@ -35,6 +35,21 @@
 /** Fills a wxControlWithItem with all input projection formats, 
   * the client data contains the associated projection number */
 WXIMPEX void FillLensProjectionList(wxControlWithItems* list);
+
+namespace HuginLensTools
+{
+    /** structure to name of lens projections and their ids */
+    struct LensInfo
+    {
+        wxString name;
+        HuginBase::BaseSrcPanoImage::Projection id;
+    };
+    /** vector of LensInfo to hold all available lens types */
+    typedef std::vector<LensInfo> LensInfoVector;
+};
+
+/** return a vector with all available projections */
+WXIMPEX HuginLensTools::LensInfoVector GetLensProjectionList();
 /** Fills a wxControlWithItem with all possible blender options,
 * the client data contains the associated blender mod from PanoramaOptions */
 WXIMPEX void FillBlenderList(wxControlWithItems* list);
@@ -80,4 +95,18 @@ WXIMPEX bool LoadLensParametersChoose(wxWindow * parent, HuginBase::Lens & lens,
  *  @returns true, if all conditions are satisfied, false if user selected cancel in dialog box */
 WXIMPEX bool CheckLensStacks(HuginBase::Panorama* pano, bool allowCancel);
 
+namespace FormatString
+{
+/** returns Exif DateTimeOriginal as formatted wxString */
+WXIMPEX wxString GetExifDateTime(const HuginBase::SrcPanoImage* img);
+/** return focallength and focallength 35 mm as wxString */
+WXIMPEX wxString GetFocalLength(const HuginBase::SrcPanoImage* img);
+/** returns formatted aperture value */
+WXIMPEX wxString GetAperture(const HuginBase::SrcPanoImage* img);
+/** returns formatted exposure time */
+WXIMPEX wxString GetExposureTime(const HuginBase::SrcPanoImage* img);
+/** returns formatted iso value */
+WXIMPEX wxString GetIso(const HuginBase::SrcPanoImage* img);
+};
+
 #endif // LENSTOOLS_H
