@@ -44,10 +44,9 @@ namespace PanoCommand
         *  beginning to end. CombinedPanoCommand deletes the commands when it is itself deleted.
         */
         CombinedPanoCommand(HuginBase::Panorama & pano, std::vector<PanoCommand*> & commands)
-            : PanoCommand(pano), commands(commands) {};
+            : PanoCommand(pano), commands(commands) { setName("multiple commands");};
         ~CombinedPanoCommand();
         virtual bool processPanorama(HuginBase::Panorama & pano);
-        virtual std::string getName() const { return "multiple commmands"; };
     private:
         std::vector<PanoCommand*> commands;
     };
@@ -56,7 +55,7 @@ namespace PanoCommand
     class WXIMPEX NewPanoCmd : public PanoCommand
     {
     public:
-        NewPanoCmd(HuginBase::Panorama & pano) : PanoCommand(pano) { m_clearDirty = true; };
+        explicit NewPanoCmd(HuginBase::Panorama & pano) : PanoCommand(pano) { m_clearDirty = true; };
         virtual bool processPanorama(HuginBase::Panorama& pano);
         virtual std::string getName() const { return "new panorama"; };
     };
@@ -185,6 +184,19 @@ namespace PanoCommand
         HuginBase::VariableMapVector vars;
     };
 
+    /** update variables by parsing a expression */
+    class WXIMPEX UpdateVariablesByParseExpression : public PanoCommand
+    {
+    public:
+        UpdateVariablesByParseExpression(HuginBase::Panorama & p, const std::string& expression)
+            : PanoCommand(p), m_expression(expression)
+        { };
+        virtual bool processPanorama(HuginBase::Panorama& pano);
+        virtual std::string getName() const { return "update image variables by parsing expression"; }
+    private:
+        std::string m_expression;
+    };
+
     /** updates the optimize vector, aka all variables which should be optimized */
     class WXIMPEX UpdateOptimizeVectorCmd : public PanoCommand
     {
@@ -238,7 +250,7 @@ namespace PanoCommand
     class WXIMPEX CenterPanoCmd : public PanoCommand
     {
     public:
-        CenterPanoCmd(HuginBase::Panorama & p) : PanoCommand(p) { };
+        explicit CenterPanoCmd(HuginBase::Panorama & p) : PanoCommand(p) { };
         virtual bool processPanorama(HuginBase::Panorama& pano);
         virtual std::string getName() const { return "center panorama"; }
     };
@@ -247,7 +259,7 @@ namespace PanoCommand
     class WXIMPEX StraightenPanoCmd : public PanoCommand
     {
     public:
-        StraightenPanoCmd(HuginBase::Panorama & p) : PanoCommand(p) { };
+        explicit StraightenPanoCmd(HuginBase::Panorama & p) : PanoCommand(p) { };
         virtual bool processPanorama(HuginBase::Panorama& pano);
         virtual std::string getName() const { return "straighten panorama"; };
     };
@@ -628,7 +640,7 @@ namespace PanoCommand
     class WXIMPEX ResetToMeanExposure : public PanoCommand
     {
     public:
-        ResetToMeanExposure(HuginBase::Panorama & p) : PanoCommand(p) { };
+        explicit ResetToMeanExposure(HuginBase::Panorama & p) : PanoCommand(p) { };
         virtual bool processPanorama(HuginBase::Panorama& pano);
         virtual std::string getName() const { return "set exposure to mean exposure"; };
     };
@@ -637,7 +649,7 @@ namespace PanoCommand
     class WXIMPEX DistributeImagesCmd : public PanoCommand
     {
     public:
-        DistributeImagesCmd(HuginBase::Panorama & p) : PanoCommand(p) { };
+        explicit DistributeImagesCmd(HuginBase::Panorama & p) : PanoCommand(p) { };
         virtual bool processPanorama(HuginBase::Panorama& pano);
         virtual std::string getName() const { return "distribute images"; };
     };
