@@ -20,10 +20,8 @@
  *
  */
 
-#ifdef __WXMAC__
 #include "panoinc_WX.h"
 #include "panoinc.h"
-#endif
 
 #include "ChoosyRemapper.h"
 #include "ViewState.h"
