@@ -248,9 +248,16 @@ void GLPanosphereOverviewRenderer::Redraw()
     double angx = m_visualization_state->getAngX();
     double angy = m_visualization_state->getAngY();
 	
-	gluLookAt(R * cos(angy) * cos(angx), R * sin(angy), R * cos(angy) * sin(angx), 0, 0, 0, 0, 1, 0);
-    //for look from inside
-//	gluLookAt(0,0,0,R * cos(angy) * cos(angx), R * sin(angy), R * cos(angy) * sin(angx), 0, 1, 0);
+    const bool insideView = m_visualization_state->isInsideView();
+    if (insideView)
+    {
+        gluLookAt(0, 0, 0, R * cos(angy) * cos(angx), R * sin(angy), R * cos(angy) * sin(angx), 0, 1, 0);
+    }
+    else
+    {
+        // view from outside
+        gluLookAt(R * cos(angy) * cos(angx), R * sin(angy), R * cos(angy) * sin(angx), 0, 0, 0, 0, 1, 0);
+    };
 
     // draw things under the preview images
     // draw each active image.
@@ -258,136 +265,168 @@ void GLPanosphereOverviewRenderer::Redraw()
     // offset by a half a pixel
     glPushMatrix();
 
-    //draw the rectangle around the sphere
-    glColor3f(0.5, 0.5, 0.5);
-    
-    double side = 150;
-    glBegin(GL_LINE_LOOP);
+    if (!insideView)
+    {
+        //draw the rectangle around the sphere
+        glColor3f(0.5, 0.5, 0.5);
 
-        glVertex3f(-side,side,0);
-        glVertex3f(side,side,0);
-        glVertex3f(side,-side,0);
-        glVertex3f(-side,-side,0);
+        double side = 150;
+        glBegin(GL_LINE_LOOP);
+            glVertex3f(-side, side, 0);
+            glVertex3f(side, side, 0);
+            glVertex3f(side, -side, 0);
+            glVertex3f(-side, -side, 0);
+        glEnd();
 
-    glEnd();
+        //draw the axes, to give a sense of orientation
+        double axis = 200;
+        glBegin(GL_LINES);
+            glColor3f(1, 0, 0);
+            glVertex3f(-axis, 0, 0);
+            glVertex3f(axis, 0, 0);
 
-    //draw the axes, to give a sense of orientation
-    double axis = 200;
-    glBegin(GL_LINES);
-
-        glColor3f(1,0,0);
-        glVertex3f(-axis,0,0);
-        glVertex3f(axis,0,0);
-
-        glColor3f(0,1,0);
-        glVertex3f(0,0,0);
-        glVertex3f(0,axis,0);
-
-        glColor3f(0,0,1);
-        glVertex3f(0,0,0);
-        glVertex3f(0,0,axis);
-
-    glEnd();
+            glColor3f(0, 1, 0);
+            glVertex3f(0, 0, 0);
+            glVertex3f(0, axis, 0);
 
+            glColor3f(0, 0, 1);
+            glVertex3f(0, 0, 0);
+            glVertex3f(0, 0, axis);
+        glEnd();
+    };
 
     glEnable(GL_TEXTURE_2D);
 
-    //To avoid z-order fight of the images if depth buffer is used, depth buffer is disabled and meshes are drawn twice,
-    //first with back faces culled so that the inner face of the sphere is visible and below the outter face, 
-    //and afterwards the meshes are drawn again with the front faces culled
-    
-    glEnable(GL_CULL_FACE);
-    glCullFace(GL_BACK);
-
-    //event called only before drawing of the images with front faces culled (the inner face of the panosphere)
-    static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->BeforeDrawImagesBack();
-    //generic draw before images are drawn (called twice with front and back faces culled)
-    m_tex_man->Begin();
-    m_tool_helper->BeforeDrawImages();
-
-    // The old preview shows the lowest numbered image on top, so do the same:
-    for (int img = imgs - 1; img != -1; img--)
+    if (insideView)
     {
-        // only draw active images
-        if (m_pano->getImage(img).getActive())
+        // in inside view we only need to draw one side of the textures, the other side is not visible at all
+        // but we need also the BeforeDrawImages[Back/Front] because all PanosphereTools were written
+        // for the outside view where back/front textures are used
+        static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->BeforeDrawImagesBack();
+        m_tex_man->Begin();
+        m_tool_helper->BeforeDrawImages();
+        // The old preview shows the lowest numbered image on top, so do the same:
+        for (int img = imgs - 1; img != -1; img--)
         {
-            // the tools can cancel drawing of images.
-            if (m_tool_helper->BeforeDrawImageNumber(img))
+            // only draw active images
+            if (m_pano->getImage(img).getActive())
             {
-                // the texture manager may need to call the display list
-                // multiple times with blending, so we pass it the display list
-                // rather than switching to the texture and then calling the
-                // list ourselves.
-                m_tex_man->DrawImage(img, m_mesh_man->GetDisplayList(img));
-                m_tool_helper->AfterDrawImageNumber(img);
+                // the tools can cancel drawing of images.
+                if (m_tool_helper->BeforeDrawImageNumber(img))
+                {
+                    // the texture manager may need to call the display list
+                    // multiple times with blending, so we pass it the display list
+                    // rather than switching to the texture and then calling the
+                    // list ourselves.
+                    m_tex_man->DrawImage(img, m_mesh_man->GetDisplayList(img));
+                    m_tool_helper->AfterDrawImageNumber(img);
+                }
             }
         }
+        // drawn things after the active image.
+        m_tool_helper->AfterDrawImages();
+        m_tex_man->End();
+        static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->AfterDrawImagesBack();
+        m_tex_man->DisableTexture();
     }
-
-    m_tex_man->End();
-    m_tool_helper->AfterDrawImages();
-    m_tex_man->DisableTexture();
-    static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->AfterDrawImagesBack();
-
-//    #ifdef __WXGTK__
-////    glCullFace(GL_BACK);
-////    glPushMatrix();
-////    glRotated(90,1,0,0);
-//////    if (imgs > 0) {
-//////        glEnable( GL_TEXTURE_2D );
-//////        glEnable(GL_BLEND);
-//////        glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-//////        glColor4f(0.5,0.5,0.5,0.5);
-//////        GLUquadric* grid = gluNewQuadric();
-//////        gluQuadricTexture(grid, GL_TRUE);
-//////        m_tex_man->BindTexture(0);
-//////        gluSphere(grid, 101,40,20);
-//////        glDisable(GL_BLEND);
-//////    } else {
-////        glColor4f(0.5,0.5,0.5,0.5);
-////        glutWireSphere(101,40,20);
-//////    }
-////    glPopMatrix();
-//    #endif
-
-    glMatrixMode(GL_MODELVIEW);
-    glCullFace(GL_FRONT);
-
-    static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->BeforeDrawImagesFront();
-
-    glEnable(GL_TEXTURE_2D);
-    m_tex_man->Begin();
-    m_tool_helper->BeforeDrawImages();
-
-    // The old preview shows the lowest numbered image on top, so do the same:
-    for (int img = imgs - 1; img != -1; img--)
+    else
     {
-        // only draw active images
-        if (m_pano->getImage(img).getActive())
+        //To avoid z-order fight of the images if depth buffer is used, depth buffer is disabled and meshes are drawn twice,
+        //first with back faces culled so that the inner face of the sphere is visible and below the outter face, 
+        //and afterwards the meshes are drawn again with the front faces culled
+
+        glEnable(GL_CULL_FACE);
+        glCullFace(GL_BACK);
+
+        //event called only before drawing of the images with front faces culled (the inner face of the panosphere)
+        static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->BeforeDrawImagesBack();
+        //generic draw before images are drawn (called twice with front and back faces culled)
+        m_tex_man->Begin();
+        m_tool_helper->BeforeDrawImages();
+
+        // The old preview shows the lowest numbered image on top, so do the same:
+        for (int img = imgs - 1; img != -1; img--)
         {
-            // the tools can cancel drawing of images.
-            if (m_tool_helper->BeforeDrawImageNumber(img))
+            // only draw active images
+            if (m_pano->getImage(img).getActive())
             {
-                // the texture manager may need to call the display list
-                // multiple times with blending, so we pass it the display list
-                // rather than switching to the texture and then calling the
-                // list ourselves.
-                m_tex_man->DrawImage(img, m_mesh_man->GetDisplayList(img));
-                m_tool_helper->AfterDrawImageNumber(img);
+                // the tools can cancel drawing of images.
+                if (m_tool_helper->BeforeDrawImageNumber(img))
+                {
+                    // the texture manager may need to call the display list
+                    // multiple times with blending, so we pass it the display list
+                    // rather than switching to the texture and then calling the
+                    // list ourselves.
+                    m_tex_man->DrawImage(img, m_mesh_man->GetDisplayList(img));
+                    m_tool_helper->AfterDrawImageNumber(img);
+                }
             }
         }
-    }
 
-    m_tex_man->End();
-    // drawn things after the active image.
-    m_tool_helper->AfterDrawImages();
-    m_tex_man->DisableTexture();
-    static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->AfterDrawImagesFront();
+        m_tex_man->End();
+        m_tool_helper->AfterDrawImages();
+        m_tex_man->DisableTexture();
+        static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->AfterDrawImagesBack();
 
-    m_tex_man->DisableTexture();
+        //    #ifdef __WXGTK__
+        ////    glCullFace(GL_BACK);
+        ////    glPushMatrix();
+        ////    glRotated(90,1,0,0);
+        //////    if (imgs > 0) {
+        //////        glEnable( GL_TEXTURE_2D );
+        //////        glEnable(GL_BLEND);
+        //////        glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+        //////        glColor4f(0.5,0.5,0.5,0.5);
+        //////        GLUquadric* grid = gluNewQuadric();
+        //////        gluQuadricTexture(grid, GL_TRUE);
+        //////        m_tex_man->BindTexture(0);
+        //////        gluSphere(grid, 101,40,20);
+        //////        glDisable(GL_BLEND);
+        //////    } else {
+        ////        glColor4f(0.5,0.5,0.5,0.5);
+        ////        glutWireSphere(101,40,20);
+        //////    }
+        ////    glPopMatrix();
+        //    #endif
 
-    glDisable(GL_CULL_FACE);
+        glMatrixMode(GL_MODELVIEW);
+        glCullFace(GL_FRONT);
 
+        static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->BeforeDrawImagesFront();
+
+        glEnable(GL_TEXTURE_2D);
+        m_tex_man->Begin();
+        m_tool_helper->BeforeDrawImages();
+
+        // The old preview shows the lowest numbered image on top, so do the same:
+        for (int img = imgs - 1; img != -1; img--)
+        {
+            // only draw active images
+            if (m_pano->getImage(img).getActive())
+            {
+                // the tools can cancel drawing of images.
+                if (m_tool_helper->BeforeDrawImageNumber(img))
+                {
+                    // the texture manager may need to call the display list
+                    // multiple times with blending, so we pass it the display list
+                    // rather than switching to the texture and then calling the
+                    // list ourselves.
+                    m_tex_man->DrawImage(img, m_mesh_man->GetDisplayList(img));
+                    m_tool_helper->AfterDrawImageNumber(img);
+                }
+            }
+        }
+
+        m_tex_man->End();
+        // drawn things after the active image.
+        m_tool_helper->AfterDrawImages();
+        m_tex_man->DisableTexture();
+        static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->AfterDrawImagesFront();
+
+        m_tex_man->DisableTexture();
+
+        glDisable(GL_CULL_FACE);
+    };
     glPopMatrix();
 }
 
@@ -421,12 +460,19 @@ vigra::Diff2D GLPanosphereOverviewRenderer::Resize(int w, int h)
     m_visualization_state->SetVisibleArea(vigra::Rect2D(0, 0, options->getWidth(),
                                              options->getHeight()));
 
-    //calculate the scale depending on the section of the panosphere in the center of the screen
-    double R = m_visualization_state->getR();
-    double radius = m_visualization_state->getSphereRadius();
-    //height of the screen in screen pixels over the length of the panosphere in panorama pixels when spread out
-    double scrscale = (float) h  / (2 * tan(fovy / 360.0 * M_PI) * (R - radius) / (2 * radius * M_PI) * (options->getWidth()));
-    m_visualization_state->SetScale(scrscale);
+    if (m_visualization_state->isInsideView())
+    {
+        m_visualization_state->SetScale(w / DEG_TO_RAD(m_visualization_state->getFOV()) / options->getWidth() * 5.0);
+    }
+    else
+    {
+        //calculate the scale depending on the section of the panosphere in the center of the screen
+        double R = m_visualization_state->getR();
+        double radius = m_visualization_state->getSphereRadius();
+        //height of the screen in screen pixels over the length of the panosphere in panorama pixels when spread out
+        double scrscale = (float)h / (2 * tan(fovy / 360.0 * M_PI) * (R - radius) / (2 * radius * M_PI) * (options->getWidth()));
+        m_visualization_state->SetScale(scrscale);
+    };
     m_visualization_state->GetViewer()->MarkToolsDirty();
 //    DEBUG_DEBUG("renderer " << scrscale << " " << h << " " << R << " " << fovy);
 //    DEBUG_DEBUG("renderer scale " << scrscale);
