@@ -23,16 +23,21 @@
 #include <wx/wx.h>
 #include <wx/platform.h>
 
-#include <GL/glew.h>
-
-#ifdef __WXMAC__
-#include <OpenGL/gl.h>
-#else
 #ifdef __WXMSW__
 #include <vigra/windows.h>
 #endif
+
+#include "hugin_config.h"
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#include <epoxy/gl.h>
+#else
+#include <GL/glew.h>
+#ifdef __WXMAC__
+#include <OpenGL/gl.h>
+#else
 #include <GL/gl.h>
 #endif
+#endif
 
 #include "panoinc.h"
 #include "ViewState.h"
