@@ -22,6 +22,16 @@
 #ifdef _WIN32
 #include "wx/msw/wrapwin.h"
 #endif
+
+#include "hugin_config.h"
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#include <epoxy/gl.h>
+#ifdef __WXMAC__
+#include <OpenGL/glu.h>
+#else
+#include <GL/glu.h>
+#endif
+#else
 #include <GL/glew.h>
 #ifdef __WXMAC__
 #include <OpenGL/gl.h>
@@ -30,6 +40,7 @@
 #include <GL/gl.h>
 #include <GL/glu.h>
 #endif
+#endif
 #ifdef __APPLE__
   #include <GLUT/glut.h>
 #endif
