@@ -23,6 +23,9 @@
  *
  */
 
+#ifdef _WIN32
+#include "wx/msw/wrapwin.h"
+#endif
 #include <hugin/PreviewColorPickerTool.h>
 #include <wx/platform.h>
 #include "GLPreviewFrame.h"
@@ -66,7 +69,7 @@ void PreviewColorPickerTool::CalcCorrection(hugin_utils::FDiff2D pos)
     m_count=0;
     HuginBase::Panorama* pano=helper->GetPanoramaPtr();
     HuginBase::UIntSet activeImages=pano->getActiveImages();
-    if(activeImages.size()>0)
+    if(!activeImages.empty())
     {
         for(HuginBase::UIntSet::iterator it=activeImages.begin();it!=activeImages.end();++it)
         {
