@@ -21,6 +21,18 @@
  *
  */
 
+#ifdef _WIN32
+#include "wx/msw/wrapwin.h"
+#endif
+#include "hugin_config.h"
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#include <epoxy/gl.h>
+#ifdef __WXMAC__
+#include <OpenGL/glu.h>
+#else
+#include <GL/glu.h>
+#endif
+#else
 #include <GL/glew.h>
 #ifdef __WXMAC__
 #include <OpenGL/gl.h>
@@ -29,6 +41,7 @@
 #include <GL/gl.h>
 #include <GL/glu.h>
 #endif
+#endif
 #ifdef __APPLE__
   #include <GLUT/glut.h>
 #endif
@@ -320,7 +333,11 @@ bool ProjectionGridTool::createTexture()
     if (!checked_anisotropic)
     {
         // check if it is supported
+#if defined HAVE_EPOXY && HAVE_EPOXY
+        if(epoxy_has_gl_extension("GL_EXT_texture_filter_anisotropic"))
+#else
         if (GLEW_EXT_texture_filter_anisotropic)
+#endif
         {
             has_anisotropic = true;
             glGetFloatv(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, &anisotropy);
