@@ -34,6 +34,15 @@ for my $file (@ARGV)
     # wxHtml does only understand the <a name=".."> style anchors, so reformat all headings to this style
     $data =~ s/<span class="mw-headline"[^>]*id="([^"]*)">(.*?)<\/span>/<a name="$1"><span class="mw-headline">$2<\/span><\/a>/gs;
     $data =~ s/<img src="([a-f0-9]{40})"/<img src="$1.png"/gs;
+    $data =~ s/<a class="mw-jump-link" href="[^>]*#mw-head">Jump to navigation<\/a>//gs;
+    $data =~ s/<a class="mw-jump-link" href="[^]]*#searchInput">Jump to search<\/a>//gs;
+    $data =~ s/(<img alt=""[^>]*class="thumbimage"[^>]*>)(<a class="external" href="https:\/\/wiki.panotools.org\/File:[^"]*">)\[\*\]<\/a>/$2$1<\/a>/gs;
+    $data =~ s/<a class="external" href="https:\/\/wiki.panotools.org\/File:[^"]*">\[\*\]<\/a>//gs;
+    $data =~ s/<li class="toclevel-3[^"]*">.*?<\/li>//gs;
+    $data =~ s/<li class="toclevel-2[^"]*">.*?<\/li>//gs;
+    $data =~ s/<li class="toclevel-1[^"]*">.*?<\/li>//gs;
+    $data =~ s/<div class="toctitle"[^>]*><h2 id="mw-toc-heading">Contents<\/h2>.*?<\/div>//gs;
+    $data =~ s/Error creating thumbnail: \/bin\/bash: line 1: rsvg-convert: command not found//gs;
     
     open FILE, ">$file";
     print FILE $data;
