@@ -215,7 +215,7 @@ wxString GetDataPath()
         wxString thePath = MacGetPathToBundledResourceFile(CFSTR("xrc"));
         if (thePath.IsEmpty())
         {
-            hugin_utils::HuginMessageBox(_("xrc directory not found in bundle"), _("PTBatcherGUI"), wxOK|wxICON_ERROR, this);
+            hugin_utils::HuginMessageBox(_("xrc directory not found in bundle"), _("PTBatcherGUI"), wxOK|wxICON_ERROR, wxGetActiveWindow());
             return wxEmptyString;
         }
         return thePath + "/";
