@@ -40,6 +40,7 @@
 #include "base_wx/MyExternalCmdExecDialog.h"
 #include "base_wx/platform.h"
 #include "base_wx/wxPlatform.h"
+#include "base_wx/wxutils.h"
 
 #include <tiffio.h>
 
@@ -74,8 +75,6 @@ private:
     void OnCancel(wxCommandEvent & event);
 
     RunStitchPanel * m_stitchPanel;
-
-    DECLARE_EVENT_TABLE()
 };
 
 // event ID's for RunStitchPanel
@@ -85,14 +84,6 @@ enum
     ID_About   
 };
 
-BEGIN_EVENT_TABLE(RunStitchFrame, wxFrame)
-    EVT_MENU(ID_Quit,  RunStitchFrame::OnQuit)
-    EVT_MENU(ID_About, RunStitchFrame::OnAbout)
-    EVT_BUTTON(wxID_CANCEL, RunStitchFrame::OnCancel)
-    EVT_END_PROCESS(-1, RunStitchFrame::OnProcessTerminate)
-    EVT_COMMAND(wxID_ANY, EVT_QUEUE_PROGRESS, RunStitchFrame::OnProgress)
-END_EVENT_TABLE()
-
 RunStitchFrame::RunStitchFrame(wxWindow * parent, const wxString& title, const wxPoint& pos, const wxSize& size)
     : wxFrame(parent, -1, title, pos, size), m_isStitching(false)
 {
@@ -102,14 +93,10 @@ RunStitchFrame::RunStitchFrame(wxWindow * parent, const wxString& title, const w
     topsizer->Add(m_stitchPanel, 1, wxEXPAND | wxALL, 2);
 
     wxBoxSizer* bottomsizer = new wxBoxSizer(wxHORIZONTAL);
-#if wxCHECK_VERSION(3,1,0)
     m_progress = new wxGauge(this, wxID_ANY, 100, wxDefaultPosition, wxDefaultSize, wxGA_HORIZONTAL | wxGA_PROGRESS);
-#else
-    m_progress = new wxGauge(this, wxID_ANY, 100, wxDefaultPosition, wxDefaultSize, wxGA_HORIZONTAL);
-#endif
     bottomsizer->Add(m_progress, 1, wxEXPAND | wxALL, 10);
     bottomsizer->Add( new wxButton(this, wxID_CANCEL, _("Cancel")),
-                   0, wxALL | wxALIGN_RIGHT, 10);
+                   0, wxALL, 10);
     topsizer->Add(bottomsizer, 0, wxEXPAND);
 
 #ifdef __WXMSW__
@@ -117,16 +104,62 @@ RunStitchFrame::RunStitchFrame(wxWindow * parent, const wxString& title, const w
     this->SetBackgroundColour(m_stitchPanel->GetBackgroundColour());
 #endif
 
+    // setup the environment for the different operating systems
+    wxInitAllImageHandlers();
+#if defined __WXMSW__
+    wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
+    exePath.RemoveLastDir();
+    wxIconBundle myIcons(exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR) + "share\\hugin\\xrc\\data\\hugin.ico", wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
+#else
+    wxString xrcPrefix;
+#if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
+    {
+        wxString exec_path = MacGetPathToBundledResourceFile(CFSTR("xrc"));
+        if (!exec_path.IsEmpty())
+        {
+            xrcPrefix = exec_path + "/";
+        }
+        else
+        {
+            hugin_utils::HuginMessageBox(_("xrc directory not found in bundle"), _("Hugin_stitch_project"), wxOK | wxICON_ERROR, wxGetActiveWindow());
+        }
+    }
+#elif defined UNIX_SELF_CONTAINED_BUNDLE
+    // initialize paths
+    {
+        wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
+        exePath.RemoveLastDir();
+        const wxString huginRoot(exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR));
+        xrcPrefix = huginRoot + "share/hugin/xrc/";
+    }
+#else
+    // add the locale directory specified during configure
+    xrcPrefix = INSTALL_XRC_DIR;
+#endif
+    if (!xrcPrefix.IsEmpty())
+    {
+        wxIcon myIcon(xrcPrefix + "data/hugin.png", wxBITMAP_TYPE_PNG);
+        SetIcon(myIcon);
+    }
+#endif
+
     SetSizer( topsizer );
 //    topsizer->SetSizeHints( this );   // set size hints to honour minimum size
     m_deleteOnExit=false;
+    // bind event handler
+    Bind(wxEVT_MENU, &RunStitchFrame::OnQuit, this, ID_Quit);
+    Bind(wxEVT_MENU, &RunStitchFrame::OnAbout, this, ID_About);
+    Bind(wxEVT_BUTTON, &RunStitchFrame::OnCancel, this, wxID_CANCEL);
+    Bind(wxEVT_END_PROCESS, &RunStitchFrame::OnProcessTerminate, this);
+    Bind(EVT_QUEUE_PROGRESS, &RunStitchFrame::OnProgress, this);
+
 }
 
 void RunStitchFrame::OnAbout(wxCommandEvent& WXUNUSED(event))
 {
-    wxMessageBox(wxString::Format(_("HuginStitchProject. Application to stitch hugin project files.\n Version: %s"), hugin_utils::GetHuginVersion().c_str()),
-                  wxT("About hugin_stitch_project"),
-                  wxOK | wxICON_INFORMATION );
+    hugin_utils::HuginMessageBox(wxString::Format(_("HuginStitchProject. Application to stitch hugin project files.\n Version: %s"), hugin_utils::GetHuginVersion()),
+                  _("Hugin_stitch_project"), wxOK | wxICON_INFORMATION, this);
 }
 void RunStitchFrame::OnQuit(wxCommandEvent& WXUNUSED(event))
 {
@@ -159,19 +192,19 @@ void RunStitchFrame::OnProcessTerminate(wxProcessEvent & event)
         m_isStitching = false;
         if (event.GetExitCode() != 0)
         {
-            if(wxMessageBox(_("Error during stitching\nPlease report the complete text to the bug tracker on https://bugs.launchpad.net/hugin.\n\nDo you want to save the log file?"),
-                _("Error during stitching"), wxICON_ERROR | wxYES_NO )==wxYES)
+            if (hugin_utils::HuginMessageBox(_("Error during stitching\nPlease report the complete text to the bug tracker on https://bugs.launchpad.net/hugin.\n\nDo you want to save the log file?"),
+                _("Hugin_stitch_project"), wxICON_ERROR | wxYES_NO, this) == wxYES)
             {
-                wxString defaultdir = wxConfigBase::Get()->Read(wxT("/actualPath"),wxT(""));
+                wxString defaultdir = wxConfigBase::Get()->Read("/actualPath",wxEmptyString);
                 wxFileDialog dlg(this,
                          _("Specify log file"),
-                         defaultdir, wxT(""),
+                         defaultdir, wxEmptyString,
                          _("Log files (*.log)|*.log|All files (*)|*"),
                          wxFD_SAVE | wxFD_OVERWRITE_PROMPT, wxDefaultPosition);
-                dlg.SetDirectory(wxConfigBase::Get()->Read(wxT("/actualPath"),wxT("")));
+                dlg.SetDirectory(wxConfigBase::Get()->Read("/actualPath",wxEmptyString));
                 if (dlg.ShowModal() == wxID_OK)
                 {
-                    wxConfig::Get()->Write(wxT("/actualPath"), dlg.GetDirectory());  // remember for later
+                    wxConfig::Get()->Write("/actualPath", dlg.GetDirectory());  // remember for later
                     m_stitchPanel->SaveLog(dlg.GetPath());
                 };
             }
@@ -264,8 +297,12 @@ stitchApp::~stitchApp()
 bool stitchApp::OnInit()
 {
     // Required to access the preferences of hugin
-    SetAppName(wxT("hugin"));
-#if defined __WXGTK__ && wxCHECK_VERSION(3,1,1)
+    SetAppName("hugin");
+#if defined __WXMSW__ && wxCHECK_VERSION(3,3,0)
+    // automatically switch between light and dark mode
+    SetAppearance(Appearance::System);
+#endif
+#if defined __WXGTK__
     CheckConfigFilename();
 #endif
 
@@ -273,7 +310,7 @@ bool stitchApp::OnInit()
     setlocale(LC_ALL, "");
     // initialize i18n
 #if defined __WXMSW__
-    int localeID = wxConfigBase::Get()->Read(wxT("language"), (long) wxLANGUAGE_DEFAULT);
+    int localeID = wxConfigBase::Get()->Read("language", (long) wxLANGUAGE_DEFAULT);
     m_locale.Init(localeID);
 #else
     m_locale.Init(wxLANGUAGE_DEFAULT);
@@ -284,7 +321,7 @@ bool stitchApp::OnInit()
     wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
     exePath.RemoveLastDir();
     // locale setup
-    m_locale.AddCatalogLookupPathPrefix(exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR) + wxT("share\\locale"));
+    m_locale.AddCatalogLookupPathPrefix(exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR) + "share\\locale");
 
 #elif defined UNIX_SELF_CONTAINED_BUNDLE
     // initialize paths
@@ -293,15 +330,15 @@ bool stitchApp::OnInit()
       exePath.RemoveLastDir();
       const wxString huginRoot=exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
       // add the locale directory specified during configure
-      m_locale.AddCatalogLookupPathPrefix(huginRoot + wxT("share/locale"));
+      m_locale.AddCatalogLookupPathPrefix(huginRoot + "share/locale");
     }
 #else
     // add the locale directory specified during configure
-    m_locale.AddCatalogLookupPathPrefix(wxT(INSTALL_LOCALE_DIR));
+    m_locale.AddCatalogLookupPathPrefix(INSTALL_LOCALE_DIR);
 #endif
 
     // set the name of locale recource to look for
-    m_locale.AddCatalog(wxT("hugin"));
+    m_locale.AddCatalog("hugin");
 
     // parse arguments
     static const wxCmdLineEntryDesc cmdLineDesc[] =
@@ -335,7 +372,7 @@ bool stitchApp::OnInit()
 
     wxString scriptFile;
 #ifdef __WXMAC__
-    m_macFileNameToOpenOnStart = wxT("");
+    m_macFileNameToOpenOnStart = wxEmptyString;
     wxYield();
     scriptFile = m_macFileNameToOpenOnStart;
     
@@ -351,28 +388,28 @@ bool stitchApp::OnInit()
 #endif
     
     wxString userDefinedOutput;
-    parser.Found(wxT("u"), &userDefinedOutput);
+    parser.Found("u", &userDefinedOutput);
     if (!userDefinedOutput.IsEmpty())
     {
         if (!wxFileName::FileExists(userDefinedOutput))
         {
-            wxMessageBox(wxString::Format(_("Could not find the specified user output file \"%s\"."), userDefinedOutput.c_str()),
-                _("Error"), wxOK | wxICON_EXCLAMATION);
+            hugin_utils::HuginMessageBox(wxString::Format(_("Could not find the specified user output file \"%s\"."), userDefinedOutput),
+                _("Hugin_stitch_project"), wxOK | wxICON_EXCLAMATION, wxGetActiveWindow());
             return false;
         };
     };
     if( parser.GetParamCount() == 0 && wxIsEmpty(scriptFile)) 
     {
-        wxString defaultdir = wxConfigBase::Get()->Read(wxT("/actualPath"),wxT(""));
+        wxString defaultdir = wxConfigBase::Get()->Read("/actualPath",wxEmptyString);
         wxFileDialog dlg(0,
                          _("Specify project source project file"),
-                         defaultdir, wxT(""),
+                         defaultdir, wxEmptyString,
                          _("Project files (*.pto)|*.pto|All files (*)|*"),
                          wxFD_OPEN, wxDefaultPosition);
 
-        dlg.SetDirectory(wxConfigBase::Get()->Read(wxT("/actualPath"),wxT("")));
+        dlg.SetDirectory(wxConfigBase::Get()->Read("/actualPath",wxEmptyString));
         if (dlg.ShowModal() == wxID_OK) {
-            wxConfig::Get()->Write(wxT("/actualPath"), dlg.GetDirectory());  // remember for later
+            wxConfig::Get()->Write("/actualPath", dlg.GetDirectory());  // remember for later
             scriptFile = dlg.GetPath();
         } else { // bail
             return false;
@@ -389,31 +426,26 @@ bool stitchApp::OnInit()
 
     wxString outname;
 
-    if ( !parser.Found(wxT("o"), &outname) ) {
+    if ( !parser.Found("o", &outname) ) {
         // ask for output.
         wxFileDialog dlg(0,_("Specify output prefix"),
-                         wxConfigBase::Get()->Read(wxT("/actualPath"),wxT("")),
-                         wxT(""), wxT(""),
+                         wxConfigBase::Get()->Read("/actualPath",wxEmptyString),
+                         wxEmptyString, wxEmptyString,
                          wxFD_SAVE, wxDefaultPosition);
-        dlg.SetDirectory(wxConfigBase::Get()->Read(wxT("/actualPath"),wxT("")));
+        dlg.SetDirectory(wxConfigBase::Get()->Read("/actualPath",wxEmptyString));
         if (dlg.ShowModal() == wxID_OK) {
             while(containsInvalidCharacters(dlg.GetPath()))
             {
-                wxMessageBox(wxString::Format(_("The given filename contains one of the following invalid characters: %s\nHugin can not work with this filename. Please enter a valid filename."),getInvalidCharacters().c_str()),
-                    _("Error"),wxOK | wxICON_EXCLAMATION);
+                hugin_utils::HuginMessageBox(wxString::Format(_("The given filename contains one of the following invalid characters: %s\nHugin can not work with this filename. Please enter a valid filename."), getInvalidCharacters()),
+                    _("Hugin_stitch_project"), wxOK | wxICON_EXCLAMATION, wxGetActiveWindow());
                 if(dlg.ShowModal()!=wxID_OK)
                     return false;
             };
             wxFileName prefix(dlg.GetPath());
             while (!prefix.IsDirWritable())
             {
-                wxMessageBox(wxString::Format(_("You have no permissions to write in folder \"%s\".\nPlease select another folder for the final output."), prefix.GetPath().c_str()),
-#ifdef __WXMSW__
-                    wxT("Hugin_stitch_project"),
-#else
-                    wxT(""),
-#endif
-                    wxOK | wxICON_INFORMATION);
+                hugin_utils::HuginMessageBox(wxString::Format(_("You have no permissions to write in folder \"%s\".\nPlease select another folder for the final output."), prefix.GetPath().c_str()),
+                    _("Hugin_stitch_project"), wxOK | wxICON_INFORMATION, wxGetActiveWindow());
                 if (dlg.ShowModal() != wxID_OK)
                 {
                     return false;
@@ -421,7 +453,7 @@ bool stitchApp::OnInit()
                 prefix = dlg.GetPath();
             };
 
-            wxConfig::Get()->Write(wxT("/actualPath"), dlg.GetDirectory());  // remember for later
+            wxConfig::Get()->Write("/actualPath", dlg.GetDirectory());  // remember for later
             outname = dlg.GetPath();
         } else { // bail
 //            wxLogError( _("No project files specified"));
@@ -433,23 +465,23 @@ bool stitchApp::OnInit()
     wxFileName outfn(outname);
     wxString ext = outfn.GetExt();
     // remove extension if it indicates an image file
-    if (ext.CmpNoCase(wxT("jpg")) == 0 || ext.CmpNoCase(wxT("jpeg")) == 0|| 
-        ext.CmpNoCase(wxT("tif")) == 0|| ext.CmpNoCase(wxT("tiff")) == 0 || 
-        ext.CmpNoCase(wxT("png")) == 0 || ext.CmpNoCase(wxT("exr")) == 0 ||
-        ext.CmpNoCase(wxT("pnm")) == 0 || ext.CmpNoCase(wxT("hdr"))) 
+    if (ext.CmpNoCase("jpg") == 0 || ext.CmpNoCase("jpeg") == 0|| 
+        ext.CmpNoCase("tif") == 0|| ext.CmpNoCase("tiff") == 0 || 
+        ext.CmpNoCase("png") == 0 || ext.CmpNoCase("exr") == 0 ||
+        ext.CmpNoCase("pnm") == 0 || ext.CmpNoCase("hdr")) 
     {
         outfn.ClearExt();
         outname = outfn.GetFullPath();
     }
 
-    RunStitchFrame *frame = new RunStitchFrame(NULL, wxT("Hugin Stitcher"), wxDefaultPosition, wxSize(640,600) );
+    RunStitchFrame *frame = new RunStitchFrame(NULL, "Hugin Stitcher", wxDefaultPosition, wxSize(640,600) );
     frame->Show( true );
     SetTopWindow( frame );
 
     wxFileName basename(scriptFile);
     frame->SetTitle(wxString::Format(_("%s - Stitching"), basename.GetName().c_str()));
-    frame->SetOverwrite(parser.Found(wxT("w")));
-    bool n = frame->StitchProject(scriptFile, outname, userDefinedOutput, parser.Found(wxT("d")));
+    frame->SetOverwrite(parser.Found("w"));
+    bool n = frame->StitchProject(scriptFile, outname, userDefinedOutput, parser.Found("d"));
     return n;
 }
 
