@@ -95,7 +95,7 @@ void rotate_erect( double x_dest, double y_dest, double* x_src, double* y_src, c
 void inv_radial( double x_dest, double y_dest, double* x_src, double* y_src, const _FuncParams &params)
 {
 	// params: double coefficients[5]
-	register double rs, rd, f, scale;
+	double rs, rd, f, scale;
 	int iter = 0;
 
 	rd	= (sqrt( x_dest*x_dest + y_dest*y_dest )) / params.var4; // Normalized
@@ -103,7 +103,7 @@ void inv_radial( double x_dest, double y_dest, double* x_src, double* y_src, con
 	rs	= rd;				
 	f 	= (((params.var3 * rs + params.var2) * rs + params.var1) * rs + params.var0) * rs;
 
-	while( abs(f - rd) > R_EPS && iter++ < MAXITER )
+	while( std::abs(f - rd) > R_EPS && iter++ < MAXITER )
 	{
 		rs = rs - (f - rd) / ((( 4 * params.var3 * rs + 3 * params.var2) * rs  +
 						  2 * params.var1) * rs + params.var0);
@@ -184,7 +184,7 @@ void vert( double x_dest, double y_dest, double* x_src, double* y_src, const _Fu
 void radial( double x_dest, double y_dest, double* x_src, double* y_src, const _FuncParams & params)
 {
 	// params: double coefficients[4], scale, correction_radius
-	register double r, scale;
+	double r, scale;
 
 	r = (sqrt( x_dest*x_dest + y_dest*y_dest )) / params.var4;
 	if( r < params.var5 )
@@ -237,7 +237,7 @@ static void deregister( double x_dest, double y_dest, double* x_src, double* y_s
 void persp_sphere( double x_dest,double  y_dest, double* x_src, double* y_src, const _FuncParams & params)
 {
 	// params :  double Matrix[3][3], double params.distance
-	register double theta,s,r;
+	double theta,s,r;
 	Vector3 v, v2;
 
 	r = sqrt( x_dest * x_dest + y_dest * y_dest );
@@ -298,7 +298,7 @@ static void pano_rect( double x_dest,double  y_dest, double* x_src, double* y_sr
 void rect_erect( double x_dest,double  y_dest, double* x_src, double* y_src, const _FuncParams & params)
 {	
 	// params: double params.distance
-	register double  phi, theta;
+	double  phi, theta;
 
 	phi 	= x_dest / params.distance;
 	theta 	=  - y_dest / params.distance  + PI / 2.0;
@@ -366,7 +366,7 @@ static void sphere_cp_erect( double x_dest,double  y_dest, double* x_src, double
 void sphere_tp_erect( double x_dest,double  y_dest, double* x_src, double* y_src, const _FuncParams & params)
 {
 	// params: double params.distance
-	register double phi, theta, r,s;
+	double phi, theta, r,s;
 	double v[3];
 	phi 	= x_dest / params.distance;
 	theta 	=  - y_dest / params.distance  + PI / 2;
@@ -407,7 +407,7 @@ static void erect_sphere_cp( double x_dest,double  y_dest, double* x_src, double
 void rect_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, const _FuncParams & params)
 {
 	// params: double params.distance
-	register double rho, theta,r;
+	double rho, theta,r;
 	r = sqrt( x_dest*x_dest + y_dest*y_dest );
 	theta 	= r / params.distance;
 
@@ -425,7 +425,7 @@ void rect_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src,
 void sphere_tp_rect( double x_dest,double  y_dest, double* x_src, double* y_src, const _FuncParams & params)
 {	
 	// params: double params.distance
-	register double  theta, r;
+	double  theta, r;
 	r = sqrt(x_dest*x_dest + y_dest*y_dest) / params.distance;
 	if( r== 0.0 )
 		theta = 1.0;
@@ -439,7 +439,7 @@ void sphere_tp_rect( double x_dest,double  y_dest, double* x_src, double* y_src,
 void sphere_tp_pano( double x_dest,double  y_dest, double* x_src, double* y_src, const _FuncParams & params)
 {
 	// params: double params.distance
-	register double r, s, Phi, theta;
+	double r, s, Phi, theta;
 	Phi = x_dest / params.distance;
 	s =  params.distance * sin( Phi ) ;	//  y' -> x
 	r = sqrt( s*s + y_dest*y_dest );
@@ -452,7 +452,7 @@ void sphere_tp_pano( double x_dest,double  y_dest, double* x_src, double* y_src,
 void pano_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, const _FuncParams & params)
 {
 	// params: double params.distance
-	register double r,s, theta;
+	double r,s, theta;
 	double v[3];
 	r = sqrt( x_dest * x_dest + y_dest * y_dest );
 	theta = r / params.distance;
@@ -491,7 +491,7 @@ void erect_rect( double x_dest,double  y_dest, double* x_src, double* y_src, con
 void erect_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, const _FuncParams & params)
 {
 	// params: double params.distance
-	register double  theta,r,s;
+	double  theta,r,s;
 	double	v[3];
 	r = sqrt( x_dest * x_dest + y_dest * y_dest );
 	theta = r / params.distance;
@@ -896,7 +896,7 @@ static double CalcCorrectionRadius_copy(double *coeff )
 static void radial_shift( double x_dest, double y_dest, double* x_src, double* y_src, const _FuncParams & params)
 {
     // params: double coefficients[4], scale, correction_radius, shift_x, shift_y
-    register double r, scale;
+    double r, scale;
 
     r = (sqrt( x_dest*x_dest + y_dest*y_dest )) / params.var4;
     if( r < params.var5 )
@@ -1204,8 +1204,8 @@ void SpaceTransform::Init(
     //int 	i;
     double	a, b;
     Matrix3 mpmt;
-    double  mpdistance, mpscale[2], mpshear[2], mprot[2], mprad[6];
-    // double mpperspect[2];
+    double  mpdistance, mpscale[2], mprot[2], mprad[6];
+    // double mpshear[2], mpperspect[2];
     double  mphorizontal, mpvertical;
 
     double  imhfov  = image.getHFOV();
@@ -1267,8 +1267,8 @@ void SpaceTransform::Init(
         }
     }
     mpscale[1]		= mpscale[0];
-    mpshear[0]		= img / imheight; // TODO : im->cP.shear_x / imheight;
-    mpshear[1]		= imt / imwidth; // TODO : im->cP.shear_y / imwidth;
+    // mpshear[0]		= img / imheight; // TODO : im->cP.shear_x / imheight;
+    // mpshear[1]		= imt / imwidth; // TODO : im->cP.shear_y / imwidth;
     mprot[0]		= mpdistance * PI;								// 180 in screenpoints
     mprot[1]		= -imyaw *  mpdistance * PI / 180.0; 			//    rotation angle in screenpoints
 
@@ -1414,8 +1414,8 @@ void SpaceTransform::InitInv(
 {
     double	a, b;
     Matrix3 mpmt;
-    double  mpdistance, mpscale[2], mpshear[2], mprot[2], mprad[6];
-//    double  mpperspect[2];
+    double  mpdistance, mpscale[2], mprot[2], mprad[6];
+//    double  mpshear[2], mpperspect[2];
     double mphorizontal, mpvertical;
 
     double  imhfov  = image.getHFOV();
@@ -1475,8 +1475,8 @@ void SpaceTransform::InitInv(
             mpscale[0] = ( pnhfov/imhfov ) * ( imwidth/pnwidth );
         }
     }
-    mpshear[0] 	= 0.0f; // TODO -im->cP.shear_x / im->height;
-    mpshear[1] 	= 0.0f; // -im->cP.shear_y / im->width;
+    // mpshear[0] 	= 0.0f; // TODO -im->cP.shear_x / im->height;
+    // mpshear[1] 	= 0.0f; // -im->cP.shear_y / im->width;
 	
     mpscale[0] = 1.0 / mpscale[0];
     mpscale[1] = mpscale[0];
