@@ -169,6 +169,12 @@ class IMPEX PanoramaOptions
             PTMENDER
         };
 
+        /** edge fill modes */
+        enum EdgeFillMode {
+            NO_EDGE_FILL = 0,
+            EDGE_FILL_SOLID = 1
+        };
+
     public:
         PanoramaOptions()
         {
@@ -232,6 +238,9 @@ class IMPEX PanoramaOptions
 
             outputStacksMinOverlap = 0.7;
             outputLayersExposureDiff = 0.5;
+
+            edgeFillMode = NO_EDGE_FILL;
+            keepEdgeFillInput = false;
         }
 
     public:
@@ -396,6 +405,10 @@ class IMPEX PanoramaOptions
         double outputStacksMinOverlap;
         double outputLayersExposureDiff;
 
+        // edge fill mode
+        EdgeFillMode edgeFillMode;
+        bool keepEdgeFillInput;
+
         pano_projection_features m_projFeatures;
 
     private:
