@@ -58,7 +58,7 @@ namespace vigra_ext {
 inline void createTiffDirectory(vigra::TiffImage * tiff, const std::string & pagename,
                                 const std::string & documentname,
                                 const std::string comp,
-                                uint16 page, uint16 nImg,
+                                uint16_t page, uint16_t nImg,
                                 vigra::Diff2D offset,
                                 vigra::Size2D fullSize,
                                 const vigra::ImageExportInfo::ICCProfile & icc)
@@ -150,8 +150,8 @@ createScalarATiffImage(ImageIterator upperleft, ImageIterator lowerright,
 
     // for alpha stuff, do not uses premultilied data
     // We do not want to throw away data by premultiplying
-    uint16 nextra_samples = 1;
-    uint16 extra_samples = EXTRASAMPLE_UNASSALPHA;
+    uint16_t nextra_samples = 1;
+    uint16_t extra_samples = EXTRASAMPLE_UNASSALPHA;
     TIFFSetField (tiff, TIFFTAG_EXTRASAMPLES, nextra_samples, &extra_samples);
 
     int bufsize = TIFFScanlineSize(tiff);
@@ -212,8 +212,8 @@ createRGBATiffImage(ImageIterator upperleft, ImageIterator lowerright,
 		
     // for alpha stuff, do not uses premultilied data
     // We do not want to throw away data & accuracy by premultiplying
-    uint16 nextra_samples = 1;
-    uint16 extra_samples = EXTRASAMPLE_UNASSALPHA;
+    uint16_t nextra_samples = 1;
+    uint16_t extra_samples = EXTRASAMPLE_UNASSALPHA;
     TIFFSetField (tiff, TIFFTAG_EXTRASAMPLES, nextra_samples, &extra_samples);
 
     int bufsize = TIFFScanlineSize(tiff);
